@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-02 14:03:12
-@LastEditTime: 2022-02-10 14:34:02
+@LastEditTime: 2022-07-19 10:50:05
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -18,7 +18,6 @@ class ActInfoHandler(ClientBaseHandler):
     """
     :description: 获取活动信息
     """
-    @filter_check_params("act_id")
     def get_async(self):
         """
         :description: 获取活动信息
@@ -26,8 +25,8 @@ class ActInfoHandler(ClientBaseHandler):
         :return: 
         :last_editors: HuangJianYi
         """
-        app_id = self.get_source_app_id()
-        act_id = int(self.get_param("act_id", 0))
+        app_id = self.get_app_id()
+        act_id = self.get_act_id()
         app_base_model = AppBaseModel(context=self)
         act_base_model = ActBaseModel(context=self)
         app_info_dict = app_base_model.get_app_info_dict(app_id)
@@ -54,7 +53,6 @@ class ActPrizeListHandler(ClientBaseHandler):
     """
     :description: 活动奖品列表
     """
-    @filter_check_params("act_id")
     def get_async(self):
         """
         :description: 活动奖品列表
@@ -67,8 +65,8 @@ class ActPrizeListHandler(ClientBaseHandler):
         :return: PageInfo
         :last_editors: HuangJianYi
         """
-        app_id = self.get_source_app_id()
-        act_id = int(self.get_param("act_id", 0))
+        app_id = self.get_app_id()
+        act_id = self.get_act_id()
         module_id = int(self.get_param("module_id", 0))
         prize_name = self.get_param("prize_name")
         page_index = int(self.get_param("page_index", 0))
@@ -97,8 +95,8 @@ class CmsInfoListHandler(ClientBaseHandler):
         :return 
         :last_editors: HuangJianYi
         """
-        app_id = self.get_source_app_id()
-        act_id = int(self.get_param("act_id", 0))
+        app_id = self.get_app_id()
+        act_id = self.get_act_id()
         place_id = int(self.get_param("place_id", 0))
         page_size = int(self.get_param("page_size", 20))
         page_index = int(self.get_param("page_index", 0))
@@ -111,7 +109,7 @@ class CmsInfoListHandler(ClientBaseHandler):
         order_by = invoke_result_data.data["order_by"] if invoke_result_data.data.__contains__("order_by") else "id desc"
         field = invoke_result_data.data["field"] if invoke_result_data.data.__contains__("field") else "*"
         cms_base_model = CmsBaseModel(context=self)
-        page_list, total = self.business_process_executed(cms_base_model.get_cms_info_list(place_id=place_id, page_size=page_size, page_index=page_index, order_by=order_by, field=field, app_id=app_id, act_id=act_id, is_cache=True), ref_params={})
+        page_list, total = cms_base_model.get_cms_info_list(place_id=place_id, page_size=page_size, page_index=page_index, order_by=order_by, field=field, app_id=app_id, act_id=act_id, is_cache=True)
         page_info = PageInfo(page_index, page_size, total, self.business_process_executed(page_list, ref_params={}))
         return self.response_json_success(page_info)
 
@@ -120,7 +118,6 @@ class PriceGearListHandler(ClientBaseHandler):
     """
     :description: 获取价格档位列表
     """
-    @filter_check_params("act_id")
     def get_async(self):
         """
         :description: 获取价格档位列表
@@ -131,8 +128,16 @@ class PriceGearListHandler(ClientBaseHandler):
         :return: list
         :last_editors: HuangJianYi
         """
-        app_id = self.get_source_app_id()
-        act_id = int(self.get_param("act_id", 0))
+        app_id = self.get_app_id()
+        act_id = self.get_act_id()
         page_index = int(self.get_param("page_index", 0))
         page_size = int(self.get_param("page_size", 20))
-        return self.response_json_success(PriceBaseModel(context=self).get_price_gear_list(app_id, act_id, page_size, page_index))
+        invoke_result_data = self.business_process_executing()
+        if invoke_result_data.success == False:
+            return self.response_json_success({"data": []})
+        if not invoke_result_data.data:
+            invoke_result_data.data = {}
+        order_by = invoke_result_data.data["order_by"] if invoke_result_data.data.__contains__("order_by") else "sort_index desc"
+        page_list, total = PriceBaseModel(context=self).get_price_gear_list(app_id, act_id, page_size, page_index, order_by)
+        page_info = PageInfo(page_index, page_size, total, self.business_process_executed(page_list, ref_params={}))
+        return self.response_json_success(page_info)
