@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-02 13:37:05
-@LastEditTime: 2022-01-06 17:02:18
+@LastEditTime: 2022-07-19 10:50:58
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -14,7 +14,6 @@ class IpInfoListHandler(ClientBaseHandler):
     """
     :description: 获取ip列表
     """
-    @filter_check_params("act_id")
     def get_async(self):
         """
         :description: 获取ip列表
@@ -24,8 +23,10 @@ class IpInfoListHandler(ClientBaseHandler):
         :return: list
         :last_editors: HuangJianYi
         """
-        app_id = self.get_source_app_id()
-        act_id = int(self.get_param("act_id", 0))
+        app_id = self.get_app_id()
+        act_id = self.get_act_id()
         page_index = int(self.get_param("page_index", 0))
         page_size = int(self.get_param("page_size", 10))
-        self.response_json_success(IpBaseModel(context=self).get_ip_info_list(app_id, act_id, page_size, page_index, condition="is_release=1"))
+        page_list, total = IpBaseModel(context=self).get_ip_info_list(app_id, act_id, page_size, page_index, condition="is_release=1")
+        page_info = PageInfo(page_index, page_size, total, self.business_process_executed(page_list, ref_params={}))
+        return self.response_json_success(page_info)
