@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-26 18:31:06
-@LastEditTime: 2022-07-20 14:16:42
+@LastEditTime: 2022-09-02 11:19:15
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -49,6 +49,8 @@ class LoginHandler(ClientBaseHandler):
         invoke_result_data = self.business_process_executing()
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
+
+        login_ip = self.get_remote_ip()
         union_id = ""
         if pt == "wx" and code:
             invoke_result_data = WeChatHelper.code2_session(code, app_id=config.get_value("app_id"), app_secret=config.get_value("app_secret"))
@@ -61,9 +63,11 @@ class LoginHandler(ClientBaseHandler):
             if invoke_result_data.success == False:
                 return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
             open_id = invoke_result_data.data["openid"]
+        else:
+            login_ip = self.get_param("source_ip")
 
         user_base_model = UserBaseModel(context=self)
-        invoke_result_data = user_base_model.save_user_by_openid(app_id, act_id, open_id, user_nick, avatar, union_id, self.get_remote_ip())
+        invoke_result_data = user_base_model.save_user_by_openid(app_id, act_id, open_id, user_nick, avatar, union_id, login_ip)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         invoke_result_data.data["user_nick"] = CryptographyHelper.emoji_base64_to_emoji(invoke_result_data.data["user_nick"])
@@ -167,6 +171,7 @@ class GetCrmIntegralHandler(ClientBaseHandler):
         :last_editors: HuangJianYi
         """
         app_id = self.get_app_id()
+        open_id = self.get_open_id()
         mix_nick = self.get_param("mix_nick")
         is_log = int(self.get_param("is_log", 0))
         is_log = True if is_log == 1 else False
@@ -179,7 +184,7 @@ class GetCrmIntegralHandler(ClientBaseHandler):
             return self.response_json_error("error", "未授权请联系客服授权")
         top_base_model = TopBaseModel(context=self)
         app_key, app_secret = self.get_app_key_secret()
-        invoke_result_data = top_base_model.get_crm_point_available(mix_nick, access_token, app_key, app_secret, is_log)
+        invoke_result_data = top_base_model.get_crm_point_available(mix_nick, access_token, app_key, app_secret, is_log, open_id)
         if invoke_result_data.success == False:
             return self.reponse_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         shop_member_integral = invoke_result_data.data
@@ -255,9 +260,10 @@ class GetCouponPrizeHandler(ClientBaseHandler):
         is_log = int(self.get_param("is_log", 0))
         is_log = True if is_log == 1 else False
         order_base_model = OrderBaseModel(context=self)
-        invoke_result_data = order_base_model.get_coupon_prize(app_id, act_id, user_id, user_prize_id, is_log)
+        app_key, app_secret = self.get_app_key_secret()
+        invoke_result_data = order_base_model.get_coupon_prize(app_id, act_id, user_id, user_prize_id, app_key, app_secret, is_log)
         if invoke_result_data.success == False:
-            return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
+            return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message, invoke_result_data.data)
         else:
             return self.response_json_success(self.business_process_executed(invoke_result_data.data, ref_params={}))
 
