@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-15 11:30:45
-@LastEditTime: 2022-07-19 15:43:07
+@LastEditTime: 2022-09-27 18:17:08
 @LastEditors: HuangJianYi
 @Description: 公共handler模块
 """
@@ -160,7 +160,7 @@ class FrameBaseHandler(BaseApiHandler):
             return True
         else:
             return False
-    
+
     def _request_source_type(self):
         """
         :Description: 请求来源类型 0-未知 1-client(客户端) 2-server(服务端)
@@ -173,7 +173,7 @@ class FrameBaseHandler(BaseApiHandler):
             return 2
         else:
             return 0
-            
+
     def _convert_request_params(self):
         """
         :Description: 转换请求参数 post请求：Content-type必须为application/json，前端必须对对象进行序列化转成json字符串，不能直接传对象,否则无法接收参数,存在特殊字符的参数必须进行url编码，否则+会被变成空值
@@ -511,23 +511,26 @@ class FrameBaseHandler(BaseApiHandler):
             act_id = config_act_id
         return act_id
 
-    def create_operation_log(self, operation_type=1, model_name="", handler_name="", old_detail=None, update_detail=None, operate_user_id="", operate_user_name=""):
+    def create_operation_log(self, operation_type=1, model_name="", handler_name="", old_detail=None, update_detail=None, operate_user_id="", operate_user_name="", operate_role_id="", title="", desc=""):
         """
         :description: 创建操作日志
         :param operation_type：操作类型：1-add，2-update，3-delete，4-review，5-copy
         :param model_name：模块或表名称
         :param handler_name：handler名称
-        :param old_detail：当前信息
-        :param update_detail：更新之后的信息
+        :param old_detail：当前对象
+        :param update_detail：更新之后的对象
         :param operate_user_id：操作人标识
         :param operate_user_name：操作人名称
+        :param operate_role_id：操作人角色标识
+        :param title：标题
+        :param desc：描述
         :return: 
         :last_editors: HuangJianYi
         """
         operation_log = OperationLog()
         operation_log_model = OperationLogModel(context=self)
 
-        operation_log.app_id = ""
+        operation_log.app_id = self.get_app_id()
         operation_log.act_id = self.get_act_id()
         operation_log.open_id = self.get_open_id()
         operation_log.user_nick = self.get_user_nick()
@@ -537,7 +540,6 @@ class FrameBaseHandler(BaseApiHandler):
         operation_log.request_host = self.request.host
         operation_log.request_uri = self.request.uri
         operation_log.remote_ip = self.get_remote_ip()
-        operation_log.create_date = TimeHelper.get_now_format_time()
         operation_log.operation_type = operation_type
         operation_log.model_name = model_name
         operation_log.handler_name = handler_name
@@ -545,6 +547,11 @@ class FrameBaseHandler(BaseApiHandler):
         operation_log.update_detail = update_detail if update_detail else {}
         operation_log.operate_user_id = operate_user_id
         operation_log.operate_user_name = operate_user_name
+        operation_log.operate_role_id = operate_role_id
+        operation_log.title = title
+        operation_log.desc = desc
+        operation_log.create_date = TimeHelper.get_now_format_time()
+        operation_log.create_day = SevenHelper.get_now_day_int()
 
         if isinstance(operation_log.request_params, dict):
             operation_log.request_params = self.json_dumps(operation_log.request_params)
