@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-03 15:42:53
-@LastEditTime: 2022-06-13 14:29:05
+@LastEditTime: 2022-06-30 13:43:16
 @LastEditors: HuangJianYi
 @Description: 活动模块
 """
@@ -196,11 +196,12 @@ class ActInfoListHandler(ClientBaseHandler):
             return self.response_json_success({"data": []})
         if not app_id:
             return self.response_json_success({"data": []})
+        app_base_model = AppBaseModel(context=self)
         act_base_model = ActBaseModel(context=self)
         page_list, total = act_base_model.get_act_info_list(app_id, act_name, is_del, page_size, page_index,False)
         for page in page_list:
-            page["online_url"] = self.get_online_url(page['id'], app_id)
-            page["live_url"] = self.get_live_url(app_id)
+            page["online_url"] = app_base_model.get_online_url(page['id'], app_id)
+            page["live_url"] = app_base_model.get_live_url(app_id)
         ref_params = {}
         page_info = PageInfo(page_index, page_size, total, self.business_process_executed(page_list, ref_params))
         return self.response_json_success(page_info)
@@ -224,6 +225,7 @@ class ActInfoHandler(ClientBaseHandler):
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         act_base_model = ActBaseModel(context=self)
+        app_base_model = AppBaseModel(context=self)
         act_info_dict = act_base_model.get_act_info_dict(act_id, False, False)
         if act_info_dict:
             if act_info_dict["app_id"] != app_id:
@@ -232,8 +234,8 @@ class ActInfoHandler(ClientBaseHandler):
             act_info_dict["share_desc_json"] = self.json_loads(act_info_dict["share_desc_json"]) if act_info_dict["share_desc_json"] else {}
             act_info_dict["rule_desc_json"] = self.json_loads(act_info_dict["rule_desc_json"]) if act_info_dict["rule_desc_json"] else []
             act_info_dict["finish_menu_config_json"] = self.json_loads(act_info_dict["finish_menu_config_json"]) if act_info_dict["finish_menu_config_json"] else []
-            act_info_dict['online_url'] = self.get_online_url(act_info_dict['id'], act_info_dict['app_id'])
-            act_info_dict['live_url'] = self.get_live_url(act_info_dict['app_id'])
+            act_info_dict['online_url'] = app_base_model.get_online_url(act_info_dict['id'], act_info_dict['app_id'])
+            act_info_dict['live_url'] = app_base_model.get_live_url(act_info_dict['app_id'])
         ref_params = {}
         return self.response_json_success(self.business_process_executed(act_info_dict, ref_params))
 
