@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-03 15:42:53
-@LastEditTime: 2022-06-13 14:34:39
+@LastEditTime: 2022-09-27 18:40:38
 @LastEditors: HuangJianYi
 @Description: 小活动模块（机台）
 """
@@ -21,6 +21,7 @@ class SaveActModuleHandler(ClientBaseHandler):
         :description: 添加活动信息
         :param app_id: 应用标识
         :param act_id: 活动标识
+        :param business_type: 业务类型(0无1机台2活动)
         :param module_id: 活动模块标识
         :param module_name: 模块名称
         :param module_sub_name: 模块短名称
@@ -51,6 +52,7 @@ class SaveActModuleHandler(ClientBaseHandler):
         """
         app_id = self.get_app_id()
         act_id = self.get_act_id()
+        business_type = int(self.get_param("business_type",0))
         module_id = int(self.get_param("module_id",0))
         module_name = self.get_param("module_name")
         module_sub_name = self.get_param("module_sub_name")
@@ -81,7 +83,7 @@ class SaveActModuleHandler(ClientBaseHandler):
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         module_base_model = ModuleBaseModel(context=self)
-        invoke_result_data = module_base_model.save_act_module(app_id, act_id, module_id, module_name, module_sub_name, start_date, end_date, module_pic, module_desc, price, price_gear_id, ip_id, join_ways, is_fictitious, sort_index, is_release, i1, i2, i3, i4, i5, s1, s2, s3, s4, s5, d1, d2)
+        invoke_result_data = module_base_model.save_act_module(app_id, act_id, module_id, module_name, module_sub_name, start_date, end_date, module_pic, module_desc, price, price_gear_id, ip_id, join_ways, is_fictitious, sort_index, is_release, i1, i2, i3, i4, i5, s1, s2, s3, s4, s5, d1, d2, business_type)
         if invoke_result_data.success ==False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         if invoke_result_data.data["is_add"] == True:
@@ -131,6 +133,7 @@ class ActModuleListHandler(ClientBaseHandler):
         """
         :description: 活动模块列表
         :param app_id：应用标识
+        :param business_type：业务类型(0无1机台2活动)
         :param act_name：模块名称
         :param start_date：开始时间
         :param end_date：结束时间
@@ -144,6 +147,7 @@ class ActModuleListHandler(ClientBaseHandler):
         page_index = int(self.get_param("page_index", 0))
         page_size = int(self.get_param("page_size", 10))
         is_del = int(self.get_param("is_del", -1))
+        business_type = int(self.get_param("business_type", -1))
         module_name = self.get_param("module_name")
         start_date = self.get_param("start_date")
         end_date = self.get_param("end_date")
@@ -156,10 +160,17 @@ class ActModuleListHandler(ClientBaseHandler):
         condition = invoke_result_data.data["condition"] if invoke_result_data.data.__contains__("condition") else ""
         params = invoke_result_data.data["params"] if invoke_result_data.data.__contains__("params") else []
         order_by = invoke_result_data.data["order_by"] if invoke_result_data.data.__contains__("order_by") else "sort_index desc,id asc"
+        condition_where = ConditionWhere()
+        if condition:
+            condition_where.add_condition(condition)
+        if business_type != -1:
+            condition_where.add_condition("business_type=%s")
+            params.append(business_type)
+
         if not app_id or not act_id:
             return self.response_json_success({"data": []})
         module_base_model = ModuleBaseModel(context=self)
-        page_list, total = module_base_model.get_act_module_list(app_id, act_id, module_name, start_date, end_date, is_del, page_size, page_index, order_by=order_by, condition=condition, params=params,is_cache=False)
+        page_list, total = module_base_model.get_act_module_list(app_id, act_id, module_name, start_date, end_date, is_del, page_size, page_index, order_by=order_by, condition=condition_where.to_string(), params=params, is_cache=False)
         ref_params = {}
         page_info = PageInfo(page_index, page_size, total, self.business_process_executed(page_list, ref_params))
         return self.response_json_success(page_info)
