@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-02 14:25:02
-@LastEditTime: 2021-11-29 16:39:56
+@LastEditTime: 2022-07-06 18:08:56
 @LastEditors: HuangJianYi
 @Description: 价格档位模块
 """
@@ -16,7 +16,7 @@ class SavePriceGearHandler(ClientBaseHandler):
     """
     :description: 保存价格档位信息
     """
-    @filter_check_params("act_id,price")
+    @filter_check_params("price")
     def get_async(self):
         """
         :description: 保存价格档位
@@ -30,11 +30,12 @@ class SavePriceGearHandler(ClientBaseHandler):
         :param goods_id：商品ID
         :param sku_id：sku_id
         :param remark：备注
+        :param sort_index：排序
         :return:
         :last_editors: HuangJianYi
         """
         app_id = self.get_app_id()
-        act_id = int(self.get_param("act_id", 0))
+        act_id = self.get_act_id()
         price_gear_id = int(self.get_param("price_gear_id", 0))
         relation_type = int(self.get_param("relation_type", 1))
         price = self.get_param("price")
@@ -43,9 +44,14 @@ class SavePriceGearHandler(ClientBaseHandler):
         goods_id = self.get_param("goods_id")
         sku_id = self.get_param("sku_id")
         remark = self.get_param("remark")
+        sort_index = int(self.get_param("sort_index", 0))
+
+        invoke_result_data = self.business_process_executing()
+        if invoke_result_data.success == False:
+            return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
 
         price_base_model = PriceBaseModel(context=self)
-        invoke_result_data = price_base_model.save_price_gear(app_id, act_id, price_gear_id, relation_type, price_gear_name, price_gear_pic, price, goods_id, sku_id,remark)
+        invoke_result_data = price_base_model.save_price_gear(app_id, act_id, price_gear_id, relation_type, price_gear_name, price_gear_pic, price, goods_id, sku_id, remark, sort_index)
         if invoke_result_data.success ==False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         if invoke_result_data.data["is_add"] == True:
@@ -53,7 +59,10 @@ class SavePriceGearHandler(ClientBaseHandler):
             self.create_operation_log(OperationType.add.value, invoke_result_data.data["new"].__str__(), "SavePriceGearHandler", None, self.json_dumps(invoke_result_data.data["new"]), self.get_open_id(), self.get_user_nick())
         else:
             self.create_operation_log(OperationType.update.value, invoke_result_data.data["new"].__str__(), "SavePriceGearHandler", self.json_dumps(invoke_result_data.data["old"]), self.json_dumps(invoke_result_data.data["new"]), self.get_open_id(), self.get_user_nick())
-
+        ref_params = {}
+        invoke_result_data = self.business_process_executed(invoke_result_data, ref_params)
+        if invoke_result_data.success == False:
+            return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         return self.response_json_success(invoke_result_data.data["new"].id)
 
 
@@ -61,7 +70,6 @@ class PriceGearListHandler(ClientBaseHandler):
     """
     :description: 获取价格档位列表
     """
-    @filter_check_params("act_id")
     def get_async(self):
         """
         :description: 获取价格档位列表
@@ -74,12 +82,19 @@ class PriceGearListHandler(ClientBaseHandler):
         :last_editors: HuangJianYi
         """
         app_id = self.get_app_id()
-        act_id = int(self.get_param("act_id", 0))
+        act_id = self.get_act_id()
         page_index = int(self.get_param("page_index", 0))
         page_size = int(self.get_param("page_size", 20))
         is_del = int(self.get_param("is_del", 0))
-
-        return self.response_json_success(PriceBaseModel(context=self).get_price_gear_list(app_id, act_id, page_size, page_index,is_del=is_del,is_cache=False))
+        invoke_result_data = self.business_process_executing()
+        if invoke_result_data.success == False:
+            return self.response_json_success({"data": []})
+        if not invoke_result_data.data:
+            invoke_result_data.data = {}
+        order_by = invoke_result_data.data["order_by"] if invoke_result_data.data.__contains__("order_by") else "sort_index desc"
+        page_list, total = PriceBaseModel(context=self).get_price_gear_list(app_id, act_id, page_size, page_index, order_by, is_del=is_del, is_cache=False)
+        page_info = PageInfo(page_index, page_size, total, self.business_process_executed(page_list, ref_params={}))
+        return self.response_json_success(page_info)
 
 
 class DeletePriceGearHandler(ClientBaseHandler):
@@ -97,7 +112,7 @@ class DeletePriceGearHandler(ClientBaseHandler):
         :last_editors: HuangJianYi
         """
         app_id = self.get_app_id()
-        act_id = int(self.get_param("act_id", 0))
+        act_id = self.get_act_id()
         price_gear_id = int(self.get_param("price_gear_id", 0))
 
         price_base_model = PriceBaseModel(context=self)
@@ -123,7 +138,7 @@ class ReviewPriceGearHandler(ClientBaseHandler):
         :last_editors: HuangJianYi
         """
         app_id = self.get_app_id()
-        act_id = int(self.get_param("act_id", 0))
+        act_id = self.get_act_id()
         price_gear_id = int(self.get_param("price_gear_id", 0))
 
         price_base_model = PriceBaseModel(context=self)
@@ -138,7 +153,7 @@ class CheckPriceGearHandler(ClientBaseHandler):
     """
     :description: 验证价格档位
     """
-    @filter_check_params("act_id,goods_id")
+    @filter_check_params("goods_id")
     def get_async(self):
         """
         :description: 验证价格档位
@@ -151,7 +166,7 @@ class CheckPriceGearHandler(ClientBaseHandler):
         :last_editors: HuangJianYi
         """
         app_id = self.get_app_id()
-        act_id = int(self.get_param("act_id", 0))
+        act_id = self.get_act_id()
         price_gear_id = int(self.get_param("price_gear_id", 0))
         goods_id = self.get_param("goods_id")
         sku_id = self.get_param("sku_id")
