@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-10-08 22:01:47
-@LastEditTime: 2022-01-26 17:11:30
+@LastEditTime: 2022-06-17 17:15:42
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -10,7 +10,8 @@ from Crypto.Cipher import AES
 import base64
 import re
 from emoji import unicode_codes
-
+import hashlib
+from seven_framework import *
 
 class CryptographyHelper:
     """
@@ -133,3 +134,28 @@ class CryptographyHelper:
             return plain_text[0:index]
         except Exception as ex:
             return ""
+
+    @classmethod
+    def signature_md5(self, request_param_dict, encrypt_key=""):
+        """
+        :description: 参数按照加密规则进行MD5加密
+        :description: 签名规则 signature_md5= ((参数1=参数1值&参数2=参数2值&signature_stamp={signature_stamp}))+密钥)进行Md5加密转小写，参数顺序按照字母表的顺序排列
+        :param request_param_dict: 请求参数字典
+        :param encrypt_key: 接口密钥
+        :return: 加密后的md5值，由于跟客户端传来的加密参数进行校验
+        """
+        request_sign_params = {}
+        for k, v in request_param_dict.items():
+            if k == "param_signature_md5":
+                continue
+            if k == "signature_md5":
+                continue
+            request_sign_params[k] = str(v).replace(" ", "_seven_").replace("(", "_seven1_").replace(")", "_seven2_")
+        request_params_sorted = sorted(request_sign_params.items(), key=lambda e: e[0], reverse=False)
+        request_message = "&".join(k + "=" + CodingHelper.url_encode(v) for k, v in request_params_sorted)
+        request_message = request_message.replace("_seven_", "%20").replace("_seven1_", "(").replace("_seven2_", ")").replace("%27", "'")
+        # MD5摘要
+        request_encrypt = hashlib.md5()
+        request_encrypt.update((request_message + str(encrypt_key)).encode("utf-8"))
+        check_request_signature_md5 = request_encrypt.hexdigest().lower()
+        return check_request_signature_md5
\ No newline at end of file
