@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-30 09:22:51
-@LastEditTime: 2022-09-16 16:02:46
+@LastEditTime: 2022-09-27 15:08:55
 @LastEditors: HuangJianYi
 @Description: 排队系统帮助类
 """
@@ -129,7 +129,7 @@ class QueueUpHelper:
         """
         user_zset_name = self._get_user_zset_name(app_id)
         redis_init = SevenHelper.redis_init()
-        return redis_init.zcount(user_zset_name, 1, 5000)
+        return redis_init.zcount(user_zset_name, 1, 1000000000000)
 
     @classmethod
     def get_user_queue_num(self, app_id, user_id):
@@ -209,7 +209,7 @@ class QueueUpHelper:
                     invoke_result_data.error_code = "queue_limit"
                     invoke_result_data.error_message = "排队失败,当前排队人数已达上限"
                     return invoke_result_data
-                queue_no = self._get_queue_no(app_id, queue_name)
+                queue_no = int(str(SevenHelper.get_now_day_int()) + str(self._get_queue_no(app_id, queue_name)).zfill(4))
                 redis_init.zadd(zset_name, {data: queue_no})
                 redis_init.expire(zset_name, expire_time)
 
@@ -366,11 +366,11 @@ class QueueUpHelper:
                             if first_is_process == True and i == 0:
                                 if now_timestamp > hash_value["end_timestamp"]:
                                     is_delete = True
-                                    self.logger_info.info("【踢掉办理用户1】" + SevenHelper.json_dumps({"zset_name": zset_name, "user_id": data, "now_timestamp": now_timestamp, "pop_timestamp": hash_value["end_timestamp"]}))
+                                    self.logger_info.info("【踢掉办理用户1】" + SevenHelper.json_dumps({"zset_name": zset_name, "first_hash_value": first_hash_value, "user_id": data, "now_timestamp": now_timestamp, "pop_timestamp": hash_value["end_timestamp"]}))
                             elif first_is_process == True and i > 0:
                                 if now_timestamp > first_end_timestamp + (i * int(config.get_value("queue_confirm_time", 8))):
                                     is_delete = True
-                                    self.logger_info.info("【踢掉办理用户2】" + SevenHelper.json_dumps({"zset_name": zset_name, "user_id": data, "now_timestamp": now_timestamp, "pop_timestamp": first_end_timestamp + (i * int(config.get_value("queue_confirm_time", 8)))}))
+                                    self.logger_info.info("【踢掉办理用户2】" + SevenHelper.json_dumps({"zset_name": zset_name, "first_hash_value": first_hash_value, "user_id": data, "now_timestamp": now_timestamp, "pop_timestamp": first_end_timestamp + (i * int(config.get_value("queue_confirm_time", 8)))}))
                             else:
                                 pop_timestamp = redis_init.hget(self._get_popdate_hash_name(app_id), zset_name)
                                 if pop_timestamp:
@@ -379,7 +379,7 @@ class QueueUpHelper:
                                     pop_timestamp = hash_value["queue_timestamp"]
                                 if now_timestamp > pop_timestamp + ((i + 1) * int(config.get_value("queue_confirm_time", 8))):
                                     is_delete = True
-                                    self.logger_info.info("【踢掉办理用户3】" + SevenHelper.json_dumps({"zset_name": zset_name, "user_id": data, "now_timestamp": now_timestamp, "pop_timestamp": pop_timestamp + ((i + 1) * int(config.get_value("queue_confirm_time", 8)))}))
+                                    self.logger_info.info("【踢掉办理用户3】" + SevenHelper.json_dumps({"zset_name": zset_name, "first_hash_value": first_hash_value, "user_id": data, "now_timestamp": now_timestamp, "pop_timestamp": pop_timestamp + ((i + 1) * int(config.get_value("queue_confirm_time", 8)))}))
 
                         if is_delete == True:
                             self._set_last_pop_date(app_id, redis_init, zset_name)
