@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-28 09:54:51
-@LastEditTime: 2022-04-28 16:22:58
+@LastEditTime: 2022-07-15 16:55:28
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -14,7 +14,9 @@ from seven_cloudapp_frame.models.db_models.act.act_type_model import *
 from seven_cloudapp_frame.models.db_models.app.app_info_model import *
 from seven_cloudapp_frame.models.db_models.act.act_info_model import *
 from seven_cloudapp_frame.models.db_models.act.act_prize_model import *
-
+from seven_cloudapp_frame.models.db_models.launch.launch_plan_model import *
+from seven_cloudapp_frame.models.db_models.launch.launch_goods_model import *
+from seven_cloudapp_frame.models.top_base_model import TopBaseModel
 
 class ActBaseModel():
     """
@@ -36,9 +38,9 @@ class ActBaseModel():
         """
         dependency_key_list = []
         if act_id:
-            dependency_key_list.append(f"act_info:actid_{act_id}") 
+            dependency_key_list.append(DependencyKey.act_info(act_id)) 
         if app_id:
-            dependency_key_list.append(f"act_info_list:appid_{app_id}")
+            dependency_key_list.append(DependencyKey.act_info_list(app_id))
         ActInfoModel().delete_dependency_key(dependency_key_list, delay_delete_time)
 
     def get_act_info_dict(self,act_id,is_cache=True,is_filter=True):
@@ -52,7 +54,7 @@ class ActBaseModel():
         """
         act_info_model = ActInfoModel(context=self.context)
         if is_cache:
-            dependency_key = f"act_info:actid_{act_id}"
+            dependency_key = DependencyKey.act_info(act_id)
             act_info_dict = act_info_model.get_cache_dict_by_id(act_id,dependency_key=dependency_key)
         else:
             act_info_dict = act_info_model.get_dict_by_id(act_id)
@@ -83,7 +85,7 @@ class ActBaseModel():
             condition += " and act_name=%s"
             params.append(act_name)
         if is_cache:
-            page_list, total = ActInfoModel(context=self.context).get_cache_dict_page_list(field="*", page_index=page_index, page_size=page_size, where=condition, group_by="", order_by=order_by, params=params,dependency_key=f"act_info_list:appid_{app_id}")
+            page_list, total = ActInfoModel(context=self.context).get_cache_dict_page_list(field="*", page_index=page_index, page_size=page_size, where=condition, group_by="", order_by=order_by, params=params,dependency_key=DependencyKey.act_info_list(app_id))
         else:
             page_list, total = ActInfoModel(context=self.context).get_dict_page_list(field="*", page_index=page_index, page_size=page_size, where=condition, group_by="", order_by=order_by, params=params)
         for page in page_list:
@@ -282,7 +284,7 @@ class ActBaseModel():
             invoke_result_data.error_code = "no_act"
             invoke_result_data.error_message = "活动信息不存在"
             return invoke_result_data
-        is_release = 0 if is_del == 1 else 1
+        is_release = 0
         modify_date = SevenHelper.get_now_datetime()
         invoke_result_data.success = act_info_model.update_table("is_del=%s,is_release=%s,release_date=%s,modify_date=%s", "id=%s", [is_del, is_release, modify_date, modify_date, act_id])
         self._delete_act_info_dependency_key(app_id,act_id)
@@ -361,3 +363,31 @@ class ActBaseModel():
             app_info_model = AppInfoModel(context=self.context)
             app_info_model.update_table("is_setting=1", "app_id=%s", [app_id])
         return invoke_result_data
+    
+    def del_act_launch(self, app_id, act_id, access_token, app_key, app_secret):
+        """
+        :description: 删除活动投放,在删除活动前调用，投放中的活动不允许删除活动
+        :param app_id：应用标识
+        :param act_id: 活动标识
+        :param access_token: access_token
+        :param app_key: app_key
+        :param app_secret: app_secret
+        :return: 
+        :last_editors: HuangJianYi
+        """
+        invoke_result_data = InvokeResultData()
+        launch_plan_model = LaunchPlanModel(context=self.context)
+        launch_plan = launch_plan_model.get_entity("act_id=%s",order_by="id desc",params=[act_id])
+        if launch_plan:
+            top_base_model = TopBaseModel(context=self.context)
+            invoke_result_data = top_base_model.miniapp_distribution_order_get(launch_plan.tb_launch_id,access_token,app_key,app_secret)
+            if invoke_result_data.success==True:
+                tb_launch_status = invoke_result_data.data["miniapp_distribution_order_get_response"]["model"]["distribution_order_open_biz_dto"][0]["status"]
+                if tb_launch_status != 2:
+                    invoke_result_data.success=False
+                    invoke_result_data.error_code="error"
+                    invoke_result_data.error_message="请先中止投放计划"
+                    return invoke_result_data
+        ActInfoModel(context=self).update_table("is_launch=0", "app_id=%s and id=%s", params=[app_id, act_id])
+        ActBaseModel(context=self)._delete_act_info_dependency_key(app_id, act_id)
+        LaunchGoodsModel(context=self).del_entity("app_id=%s and act_id=%s", params=[app_id, act_id])
\ No newline at end of file
