@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-28 09:54:51
-@LastEditTime: 2022-07-26 09:09:05
+@LastEditTime: 2022-09-27 09:09:42
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -16,7 +16,7 @@ from seven_cloudapp_frame.models.db_models.friend.friend_link_model import *
 from seven_cloudapp_frame.models.db_models.product.product_price_model import *
 from seven_cloudapp_frame.models.db_models.tao.tao_login_log_model import *
 from seven_cloudapp_frame.models.db_models.version.version_info_model import *
-
+from seven_cloudapp_frame.models.db_models.dict.dict_info_model import *
 
 class AppBaseModel():
     """
@@ -273,4 +273,100 @@ class AppBaseModel():
         :last_editors: HuangJianYi
         """
         live_url = f"https://market.m.taobao.com/app/taefed/shopping-delivery-wapp/index.html#/putin?mainKey=form&appId={app_id}"
-        return live_url
\ No newline at end of file
+        return live_url
+
+    def _delete_dict_info_dependency_key(self, parent_id, delay_delete_time=0.01):
+        """
+        :description: 删除字典信息依赖建
+        :param parent_id: 父节点标识
+        :param delay_delete_time: 延迟删除时间，传0则不进行延迟
+        :return: 
+        :last_editors: HuangJianYi
+        """
+        CmsDictInfoModel().delete_dependency_key(DependencyKey.dict_info_list(parent_id), delay_delete_time)
+
+    def save_dict_info(self, parent_id, dict_id, dict_name, dict_value, dict_pic, sort_index, is_release, i1, i2, s1, s2):
+        """
+        :description: 保存字典
+        :param parent_id: 父节点标识
+        :param dict_name：字典名称
+        :param dict_value：字典值
+        :param dict_pic：字典图片
+        :param sort_index：排序
+        :param is_release：是否发布
+        :param i1：i1
+        :param i2：i2
+        :param s1：s1
+        :param s2：s2
+        :return
+        :last_editors: HuangJianYi
+        """
+        invoke_result_data = InvokeResultData()
+        if not parent_id or not dict_name:
+            invoke_result_data.success = False
+            invoke_result_data.error_code = "param_error"
+            invoke_result_data.error_message = "参数不能为空或等于0"
+            return invoke_result_data
+        old_dict_info = None
+        dict_info = None
+        is_add = False
+        dict_info_model = DictInfoModel(context=self.context)
+        if dict_id > 0:
+            dict_info = dict_info_model.get_entity_by_id(dict_id)
+            if not dict_info:
+                invoke_result_data.success = False
+                invoke_result_data.error_code = "error"
+                invoke_result_data.error_message = "信息不存在"
+                return invoke_result_data
+            old_dict_info = deepcopy(dict_info)
+        if not dict_info:
+            is_add = True
+            dict_info = DictInfo()
+        dict_info.parent_id = parent_id
+        dict_info.dict_name = dict_name
+        dict_info.dict_value = dict_value
+        dict_info.dict_pic = dict_pic
+        dict_info.sort_index = sort_index
+        dict_info.is_release = is_release
+        dict_info.i1 = i1
+        dict_info.i2 = i2
+        dict_info.s1 = s1
+        dict_info.s2 = s2
+        dict_info.modify_date = SevenHelper.get_now_datetime()
+        if is_add:
+            dict_info.create_date = dict_info.modify_date
+            dict_info.id = dict_info_model.add_entity(dict_info)
+        else:
+            dict_info_model.update_entity(dict_info,exclude_field_list="parent_id,create_date")
+        result = {}
+        result["is_add"] = is_add
+        result["new"] = dict_info
+        result["old"] = old_dict_info
+        invoke_result_data.data = result
+        self._delete_dict_info_dependency_key(parent_id)
+        return invoke_result_data
+
+    def get_dict_info_list(self, parent_id, page_size, page_index, order_by="id desc",field="*", is_cache=True):
+        """
+        :description: 字典列表
+        :param parent_id：父节点标识
+        :param page_size：页大小
+        :param page_index：页索引
+        :param order_by：排序
+        :param field：查询字段
+        :param is_cache：是否缓存
+        :return:
+        :last_editors: HuangJianYi
+        """
+        page_list = []
+        total = 0
+        if not parent_id:
+            return page_list, total
+        condition = "parent_id=%s and is_release=1"
+        params = [parent_id]
+        dict_info_model = DictInfoModel(context=self.context)
+        if is_cache == True:
+            page_list, total = dict_info_model.get_cache_dict_page_list(field=field, page_index=page_index, page_size=page_size, where=condition, group_by="", order_by=order_by,params=params,dependency_key=DependencyKey.dict_info_list(parent_id),cache_expire=600)
+        else:
+            page_list, total = dict_info_model.get_dict_page_list(field=field, page_index=page_index, page_size=page_size, where=condition, group_by="", order_by=order_by,params=params)
+        return page_list, total
\ No newline at end of file
