@@ -2,7 +2,7 @@
 """
 :Author: HuangJianYi
 :Date: 2020-03-06 23:17:54
-@LastEditTime: 2022-07-19 14:26:58
+@LastEditTime: 2022-08-12 18:25:35
 @LastEditors: HuangJianYi
 :Description: 数据缓存业务模型
 """
@@ -469,16 +469,18 @@ class CacheModel(BaseModel):
         if list and config.get_value("is_redis_cache",True) == True:
             return list
         else:
-            list = self.db.fetch_all_rows(sql, params)
+            list_row = self.db.fetch_all_rows(sql, params)
+            if not list_row:
+                list_row = []
             config_cache_expire = config.get_value("cache_expire",0)
             if config_cache_expire > 0:
                 cache_expire = config_cache_expire
-            self.set_dependency_cache(dependency_key,cache_key,list,cache_expire)
-            if list and len(list) > 0:
-                for one_row in list:
+            self.set_dependency_cache(dependency_key,cache_key,list_row,cache_expire)
+            if list_row and len(list_row) > 0:
+                for one_row in list_row:
                     for field in one_row:
                         one_row[field] = self._BaseModel__convert_field_type(one_row[field])
-            return list
+            return list_row
 
     def get_cache_dict_page_list(self, field="*", page_index=0 ,page_size=20, where='', group_by='' ,order_by='' ,params=None, dependency_key='', cache_expire=600):
         """
@@ -513,6 +515,8 @@ class CacheModel(BaseModel):
         else:
             list_row = self.db.fetch_all_rows(sql, params)
             row = self.db.fetch_one_row(count_sql, params)
+            if not list_row:
+                list_row = []
             if row and 'count' in row and int(row['count']) > 0:
                 row_count = int(row["count"])
             else:
