@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-11-26 10:22:44
-@LastEditTime: 2022-06-14 14:02:35
+@LastEditTime: 2022-09-27 09:09:24
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -13,7 +13,7 @@ from seven_cloudapp_frame.models.db_models.cms.cms_info_model import *
 
 class CmsBaseModel():
     """
-    :description: 位置信息（资讯）相关业务模型 用于后台或者中台案例和教程等配置信息
+    :description: 位置信息（资讯）相关业务模型 用于后台或者中台案例和教程等配置信息、字典表用于管理标签、分类等信息
     """
     def __init__(self,context=None,logging_error=None,logging_info=None):
         self.context = context
