@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-11-24 09:36:39
-@LastEditTime: 2022-04-28 14:59:32
+@LastEditTime: 2022-05-20 09:05:10
 @LastEditors: HuangJianYi
 @Description: ERP控制台业务模型(用于跟遁甲系统对接，推送订单和回写物流) 需在配置文件加 armor_url 和 armor_sign_key对应的值
 """
@@ -56,8 +56,6 @@ class ErpConsoleModel():
             try:
                 time.sleep(0.1)
                 erp_relation_model = ErpRelationModel()
-                act_info_model = ActInfoModel()
-                frame_base_model = FrameBaseModel(None)
                 now_date = TimeHelper.get_now_format_time()
                 if mod_count == 1:
                     erp_relation_list = erp_relation_model.get_dict_list("is_release=1 and %s>sync_date and start_date<=%s and end_date>=%s", order_by="sync_date asc", limit="100", params=[TimeHelper.add_minutes_by_format_time(minute=-10), now_date, now_date])
@@ -67,32 +65,30 @@ class ErpConsoleModel():
                     for erp_relation_dict in erp_relation_list:
                         try:
                             erp_relation_model.update_table("sync_date=%s", "id=%s", params=[TimeHelper.get_now_format_time(), erp_relation_dict["id"]])
-                            act_info_dict_list = act_info_model.get_dict_list("app_id=%s and is_release=1", field="id", params=[erp_relation_dict["app_id"]])
-                            if len(act_info_dict_list) > 0:
-                                for act_info_dict in act_info_dict_list:
-                                    prize_order_model = PrizeOrderModel(sub_table=frame_base_model.get_business_sub_table("prize_order_tb", {"act_id": act_info_dict["id"], "user_id": 0}))
-                                    prize_roster_model = PrizeRosterModel(sub_table=frame_base_model.get_business_sub_table("prize_roster_tb", {"act_id": act_info_dict["id"], "user_id": 0}))
-                                    condition = "app_id=%s and order_status=0 and sync_status=0"
-                                    params = [erp_relation_dict["app_id"]]
-                                    record_count = prize_order_model.get_total(condition, params=params)
-                                    page_count = SevenHelper.get_page_count(page_size, record_count)
-                                    for page_index in range(page_count):
-                                        prize_order_list_dict, total = prize_order_model.get_dict_page_list("*", page_index, page_size, condition, "", "id asc", params)
-                                        for prize_order_dict in prize_order_list_dict:
-                                            request_params = self.compose_push_request_params(sign_key, erp_relation_dict, prize_order_dict, prize_roster_model)
-                                            request_params = self.process_order_push_executed(request_params, erp_relation_dict)
-                                            if request_params["goods"]:
-                                                result = HTTPHelper.post(push_url, request_params, {"Content-Type": "application/json"})
-                                                if result and result.ok:
-                                                    prize_order_model.update_table("sync_status=1,sync_date=%s", "id=%s", params=[TimeHelper.get_now_format_time(), prize_order_dict["id"]])
-                                                else:
-                                                    prize_order_dict["sync_count"] = prize_order_dict["sync_count"] + 1
-                                                    if prize_order_dict["sync_count"] == 10:
-                                                        prize_order_model.update_table("sync_status=2,sync_date=%s,sync_result=%s", "id=%s", params=[TimeHelper.get_now_format_time(), result, prize_order_dict["id"]])
-                                                    else:
-                                                        prize_order_model.update_table("sync_count=sync_count+1,sync_date=%s,sync_result=%s", "id=%s", params=[TimeHelper.get_now_format_time(), result, prize_order_dict["id"]])
+                            prize_order_model = PrizeOrderModel()
+                            prize_roster_model = PrizeRosterModel()
+                            condition = "app_id=%s and order_status=0 and sync_status=0"
+                            params = [erp_relation_dict["app_id"]]
+                            record_count = prize_order_model.get_total(condition, params=params)
+                            page_count = SevenHelper.get_page_count(page_size, record_count)
+                            for page_index in range(page_count):
+                                prize_order_list_dict = prize_order_model.get_dict_list(condition, "", order_by="id asc", limit=str(page_size), field="*", params=params)
+                                for prize_order_dict in prize_order_list_dict:
+                                    request_params = self.compose_push_request_params(sign_key, erp_relation_dict, prize_order_dict, prize_roster_model)
+                                    request_params = self.process_order_push_executed(request_params, erp_relation_dict)
+                                    if request_params["goods"]:
+                                        result = HTTPHelper.post(push_url, request_params, {"Content-Type": "application/json"})
+                                        if result and result.ok:
+                                            prize_order_model.update_table("sync_status=1,sync_date=%s", "id=%s", params=[TimeHelper.get_now_format_time(), prize_order_dict["id"]])
+                                        else:
+                                            prize_order_dict["sync_count"] = prize_order_dict["sync_count"] + 1
+                                            if prize_order_dict["sync_count"] == 10:
+                                                prize_order_model.update_table("sync_status=2,sync_date=%s,sync_result=%s", "id=%s", params=[TimeHelper.get_now_format_time(), SevenHelper.json_dumps(result), prize_order_dict["id"]])
                                             else:
-                                                prize_order_model.update_table("sync_status=2,sync_date=%s,sync_result=%s", "id=%s", params=[TimeHelper.get_now_format_time(), "推送订单失败，没有商品信息", prize_order_dict["id"]])
+                                                prize_order_model.update_table("sync_count=sync_count+1,sync_date=%s,sync_result=%s", "id=%s", params=[TimeHelper.get_now_format_time(), SevenHelper.json_dumps(result), prize_order_dict["id"]])
+                                    else:
+                                        prize_order_model.update_table("sync_status=2,sync_date=%s,sync_result=%s", "id=%s", params=[TimeHelper.get_now_format_time(), "推送订单失败，没有商品信息", prize_order_dict["id"]])
+
                         except Exception as ex:
                             logger_error.error(f"推送订单队列{mod_value}异常,json串:{SevenHelper.json_dumps(erp_relation_dict)},ex:{traceback.format_exc()}")
                             continue
@@ -190,6 +186,8 @@ class ErpConsoleModel():
         while True:
             try:
                 time.sleep(0.1)
+                prize_order_model = PrizeOrderModel()
+                prize_roster_model = PrizeRosterModel()
                 now_date = TimeHelper.get_now_format_time()
                 if mod_count == 1:
                     erp_relation_list = erp_relation_model.get_dict_list("is_release=1 and %s>return_date and start_date<=%s and end_date>=%s", order_by="return_date asc", limit="100", params=[TimeHelper.add_minutes_by_format_time(minute=-10), now_date, now_date])
@@ -211,9 +209,6 @@ class ErpConsoleModel():
                                     if not order_info_json:
                                         break
                                     order_info_dict = json.loads(order_info_json)
-                                    act_id = int(order_info_dict["activity_id"]) if order_info_dict["activity_id"] else 0
-                                    prize_order_model = PrizeOrderModel(sub_table=frame_base_model.get_business_sub_table("prize_order_tb", {"act_id": act_id, "user_id": 0}))
-                                    prize_roster_model = PrizeRosterModel(sub_table=frame_base_model.get_business_sub_table("prize_roster_tb", {"act_id": act_id, "user_id": 0}))
                                     order_status = order_info_dict["order_status"]
                                     order_no = order_info_dict["mini_order"]
                                     express_no = order_info_dict["logistics_number"]
