@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-19 13:37:16
-@LastEditTime: 2022-07-14 10:48:53
+@LastEditTime: 2022-08-25 16:15:34
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -16,7 +16,8 @@ from seven_cloudapp_frame.models.db_models.stat.stat_queue_model import *
 from seven_cloudapp_frame.models.db_models.stat.stat_orm_model import *
 from seven_cloudapp_frame.models.db_models.stat.stat_report_model import *
 from seven_cloudapp_frame.models.db_models.stat.stat_log_model import *
-
+from seven_cloudapp_frame.models.db_models.stat.stat_user_report_model import *
+from seven_cloudapp_frame.models.db_models.stat.stat_user_log_model import *
 
 class StatConsoleModel():
     """
@@ -29,22 +30,37 @@ class StatConsoleModel():
         :return: 
         :last_editors: HuangJianYi
         """
+        stat_config = config.get_value("stat_config", {})
+        is_process_stat = stat_config.get("is_process_stat", True)
+        if is_process_stat:
+            stat_process_ways = config.get_value("stat_process_ways","mysql")
+            if stat_process_ways == "mysql":
+                for i in range(mod_count):
+                    t = threading.Thread(target=self._process_stat_queue, args=[i, mod_count])
+                    t.start()
+            else:
+                for i in range(10):
+                    j = threading.Thread(target=self._process_redis_stat_queue, args=[i])
+                    j.start()
 
-        stat_process_ways = config.get_value("stat_process_ways","mysql")
-        if stat_process_ways == "mysql":
-            for i in range(mod_count):
-                t = threading.Thread(target=self._process_stat_queue, args=[i, mod_count])
-                t.start()
-        else:
+            clea_data_work = ClearDataWork()
+            clea_data_work.start_hours = 2
+            clea_data_work.end_hours = 4
+            clea_data_work.sleep_time = 3600
+            clea_data_work.start_work("清理统计流水数据作业")
+
+        is_process_stat_user = stat_config.get("is_process_stat_user",False)
+        if is_process_stat_user:
             for i in range(10):
-                j = threading.Thread(target=self._process_redis_stat_queue, args=[i])
-                j.start()
+                k = threading.Thread(target=self._process_redis_stat_user_queue, args=[i])
+                k.start()
+
+            stat_user_data_work = StatUserDataWork()
+            stat_user_data_work.start_hours = 2
+            stat_user_data_work.end_hours = 4
+            stat_user_data_work.sleep_time = 3600
+            stat_user_data_work.start_work("处理统计用户数据作业")
 
-        clea_data_work = ClearDataWork()
-        clea_data_work.start_hours = 3
-        clea_data_work.end_hours = 4
-        clea_data_work.sleep_time = 3600
-        clea_data_work.start_work("清理统计流水数据作业")
 
     def _process_stat_queue(self, mod_value, mod_count):
         """
@@ -69,9 +85,8 @@ class StatConsoleModel():
                 if len(stat_queue_list) > 0:
                     for stat_queue in stat_queue_list:
                         try:
-                            frame_base_model = FrameBaseModel(None)
-                            stat_log_model = StatLogModel(sub_table=frame_base_model.get_business_sub_table("stat_log_tb", {"act_id": stat_queue.act_id, "user_id": stat_queue.user_id}), db_transaction=db_transaction)
-                            stat_report_model = StatReportModel(sub_table=frame_base_model.get_business_sub_table("stat_report_tb", {"act_id": stat_queue.act_id, "user_id": 0}), db_transaction=db_transaction)
+                            stat_log_model = StatLogModel(db_transaction=db_transaction)
+                            stat_report_model = StatReportModel(db_transaction=db_transaction)
                             stat_orm = stat_orm_model.get_cache_entity("((act_id=%s and module_id=%s) or (act_id=0 and module_id=0)) and key_name=%s", params=[stat_queue.act_id, stat_queue.module_id, stat_queue.key_name])
                             if not stat_orm:
                                 stat_queue_model.del_entity("id=%s", params=[stat_queue.id])
@@ -166,9 +181,8 @@ class StatConsoleModel():
                     continue
                 try:
                     stat_queue_dict = SevenHelper.json_loads(stat_queue_json)
-                    frame_base_model = FrameBaseModel(context=None)
-                    stat_log_model = StatLogModel(sub_table=frame_base_model.get_business_sub_table("stat_log_tb", {"act_id": stat_queue_dict["act_id"], "user_id": stat_queue_dict["user_id"]}), db_transaction=db_transaction)
-                    stat_report_model = StatReportModel(sub_table=frame_base_model.get_business_sub_table("stat_report_tb", {"act_id": stat_queue_dict["act_id"], "user_id": 0}), db_transaction=db_transaction)
+                    stat_log_model = StatLogModel(db_transaction=db_transaction)
+                    stat_report_model = StatReportModel(db_transaction=db_transaction)
                     stat_orm = stat_orm_model.get_cache_entity("((act_id=%s and module_id=%s) or (act_id=0 and module_id=0)) and key_name=%s", params=[stat_queue_dict["act_id"], stat_queue_dict["module_id"], stat_queue_dict["key_name"]])
                     if not stat_orm:
                         redis_init.lpop(redis_stat_key)
@@ -236,6 +250,86 @@ class StatConsoleModel():
                 logger_error.error(f"统计队列{mod_value}异常,ex:{traceback.format_exc()}")
                 time.sleep(5)
 
+    def _process_redis_stat_user_queue(self, mod_value):
+        """
+        :description: 处理redis统计用户队列
+        :param mod_value: 当前队列值
+        :return: 
+        :last_editors: HuangJianYi
+        """
+        print(f"{TimeHelper.get_now_format_time()} 统计用户队列{mod_value}启动")
+
+        while True:
+            try:
+                time.sleep(0.1)
+                db_transaction = DbTransaction(db_config_dict=config.get_value("db_cloudapp"))
+                redis_init = SevenHelper.redis_init()
+                redis_stat_key = f"stat_user_queue_list:{mod_value}"
+                stat_queue_json = redis_init.lindex(redis_stat_key, index=0)
+                if not stat_queue_json:
+                    time.sleep(1)
+                    continue
+                try:
+                    stat_queue_dict = SevenHelper.json_loads(stat_queue_json)
+                    stat_user_log_model = StatUserLogModel(db_transaction=db_transaction)
+                    stat_user_report_model = StatUserReportModel(db_transaction=db_transaction)
+                    create_date = TimeHelper.format_time_to_datetime(stat_queue_dict["create_date"])
+                    create_day_int = int(create_date.strftime('%Y%m%d'))
+                    create_month_int = int(create_date.strftime('%Y%m'))
+                    create_year_int = int(create_date.strftime('%Y'))
+                    field_name = stat_queue_dict["key_name"]
+
+                    stat_log = StatLog()
+                    stat_log.app_id = stat_queue_dict["app_id"]
+                    stat_log.act_id = stat_queue_dict["act_id"]
+                    stat_log.module_id = stat_queue_dict["module_id"]
+                    stat_log.user_id = stat_queue_dict["user_id"]
+                    stat_log.open_id = stat_queue_dict["open_id"]
+                    stat_log.key_name = field_name
+                    stat_log.key_value = stat_queue_dict["key_value"]
+                    stat_log.create_day = create_day_int
+                    stat_log.create_month = create_month_int
+                    stat_log.create_date = create_date
+
+                    stat_report_condition = "act_id=%s and module_id=%s and create_day=%s and user_id=%s"
+                    stat_report_param = [stat_queue_dict["act_id"], stat_queue_dict["module_id"], create_day_int, stat_queue_dict["user_id"]]
+                    stat_report_total = stat_user_report_model.get_total(stat_report_condition, params=stat_report_param)
+                    if stat_report_total == 0:
+                        stat_user_report = StatUserReport()
+                        stat_user_report.app_id = stat_queue_dict["app_id"]
+                        stat_user_report.act_id = stat_queue_dict["act_id"]
+                        stat_user_report.module_id = stat_queue_dict["module_id"]
+                        stat_user_report.user_id = stat_queue_dict["user_id"]
+                        stat_user_report.open_id = stat_queue_dict["open_id"]
+                        stat_user_report.key_name = field_name
+                        stat_user_report.key_value = stat_queue_dict["key_value"]
+                        stat_user_report.create_date = create_date
+                        stat_user_report.create_year = create_year_int
+                        stat_user_report.create_month = create_month_int
+                        stat_user_report.create_day = create_day_int
+                        stat_user_report_model.add_entity(stat_user_report)
+
+                    db_transaction.begin_transaction()
+                    key_value = stat_queue_dict["key_value"]
+                    stat_user_report_model.update_table(f"{field_name}={field_name}+{key_value}", stat_report_condition, params=stat_report_param)
+                    stat_user_log_model.add_entity(stat_log)
+                    result,message = db_transaction.commit_transaction(True)
+                    if result == False:
+                        raise Exception("执行事务失败", message)
+
+                    redis_init.lpop(redis_stat_key)
+
+                except Exception as ex:
+                    if db_transaction.is_transaction == True:
+                        db_transaction.rollback_transaction()
+                    logger_error.error(f"统计用户队列{mod_value}异常,json串:{SevenHelper.json_dumps(stat_queue_dict)},ex:{traceback.format_exc()}")
+                    continue
+
+            except Exception as ex:
+                logger_error.error(f"统计用户队列{mod_value}异常,ex:{traceback.format_exc()}")
+                time.sleep(5)
+
+
 class ClearDataWork(TimingWork):
     """
     :description: 清理数据
@@ -244,13 +338,7 @@ class ClearDataWork(TimingWork):
     """
     def execute(self):
         invoke_result_data = InvokeResultData()
-        sub_table_config_list = config.get_value("sub_table_config_list",{})
-        sub_table_config = sub_table_config_list.get("stat_log_tb",{"sub_count":0,"sub_ways":0}) #sub_count分表数量，sub_ways分表方式（0-默认1-活动id取模2-用户id取模）
-        sub_count = sub_table_config.get("sub_count", 0)
-        if sub_count > 0:
-            self.process_sub_table(sub_count)
-        else:
-            self.process_only_table()
+        self.process_only_table()
 
         return invoke_result_data
 
@@ -270,30 +358,54 @@ class ClearDataWork(TimingWork):
             for stat_orm_dict in stat_orm_dict_list:
                 if stat_orm_dict["repeat_type"] != 2:
                     while True:
-                        is_del = stat_log_model.del_entity("orm_id=%s and create_day<%s", params=[stat_orm_dict["id"], SevenHelper.get_now_day_int(-24 * 15)], limit="1000")
+                        is_del = stat_log_model.del_entity("orm_id=%s and create_day<%s", params=[stat_orm_dict["id"], SevenHelper.get_now_day_int(-24 * 15)], limit="100")
                         if is_del == False:
                             break
             page_index += 1
 
-    def process_sub_table(self, sub_count):
+
+class StatUserDataWork(TimingWork):
+    """
+    :description: 处理统计用户数据（用户汇总报表只保留1年的记录，流水只保留1个月）
+    :return: 
+    :last_editors: HuangJianYi
+    """
+
+    def execute(self):
+        invoke_result_data = InvokeResultData()
+        self.clear_log()
+        self.clear_report()
+        return invoke_result_data
+
+    def clear_log(self):
         """
-        :description: 处理分表
-        :param sub_count: 分表数量
+        :description: 清理流水
         :return: 
         :last_editors: HuangJianYi
         """
-        stat_orm_model = StatOrmModel()
-        page_index = 0
+        stat_log_model = StatUserLogModel()
+        stat_config = config.get_value("stat_config", {})
+        space_day = int(stat_config.get("user_log_space_day", 30))
         while True:
-            stat_orm_dict_list, total = stat_orm_model.get_dict_page_list(field="id,repeat_type", page_index=page_index, page_size=50, order_by="id asc")
-            if len(stat_orm_dict_list) <= 0:
+            is_del = stat_log_model.del_entity("create_day<%s", params=[SevenHelper.get_now_day_int(-24 * space_day)], limit="100")
+            if is_del == False:
                 break
-            for stat_orm_dict in stat_orm_dict_list:
-                if stat_orm_dict["repeat_type"] != 2:
-                    for i in range(sub_count):
-                        stat_log_model = StatLogModel(sub_table=str(i))
-                        while True:
-                            is_del = stat_log_model.del_entity("orm_id=%s and create_day<%s", params=[stat_orm_dict["id"], SevenHelper.get_now_day_int(-24 * 15)], limit="500")
-                            if is_del == False:
-                                break
-            page_index += 1
+
+    def clear_report(self):
+        """
+        :description: 清理报表(用户统计表需要按年创建分表，然后把数据加入到对应的年分表中，没建表则无法清理报表)
+        :return: 
+        :last_editors: HuangJianYi
+        """
+        stat_user_report_model = StatUserReportModel()
+        stat_config = config.get_value("stat_config",{})
+        space_day = int(stat_config.get("user_report_space_day", 365))
+        while True:
+            stat_user_report_list = stat_user_report_model.get_list(where="create_day<%s", order_by="id asc", limit="100", params=[SevenHelper.get_now_day_int(-24 * space_day)])
+            if len(stat_user_report_list) <= 0:
+                break
+            for item in stat_user_report_list:
+                create_year = item.create_year
+                stat_user_report_year_model = StatUserReportModel(sub_table=f"{create_year}")
+                stat_user_report_year_model.add_entity(item)
+                stat_user_report_model.del_entity("id=%s", params=[item.id])
