@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-15 17:17:08
-@LastEditTime: 2021-10-11 16:24:40
+@LastEditTime: 2022-07-07 14:57:06
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -35,7 +35,7 @@ class AssetLog:
         self.user_nick = ""  # 昵称
         self.log_title = ""  # 标题
         self.info_json = ""  # 详情信息
-        self.asset_type = 0  # 资产类型(1-次数2-积分3-价格档位)
+        self.asset_type = 0  # 资产类型(1-次数2-积分3-价格档位，业务自定义类型从101起，避免跟公共冲突)
         self.asset_object_id = ""  # 资产对象标识（比如资产类型是价格档位则对应档位id）
         self.source_type = 0  # 来源类型（1-购买2-任务3-手动配置4-抽奖5-回购.业务自定义类型从101起，避免跟公共冲突）
         self.source_object_id = ""  # 来源对象标识(比如来源类型是任务则对应任务类型)
