@@ -20,6 +20,7 @@ class AssetWarnNotice:
         self.id = 0  # id
         self.app_id = ""  # 应用标识
         self.act_id = 0  # 活动标识
+        self.ascription_type = 1 # 归属类型(1-预警2-拦截)
         self.user_id = 0  # 用户标识
         self.open_id = ""  # open_id
         self.user_nick = ""  # 用户昵称
@@ -37,7 +38,7 @@ class AssetWarnNotice:
 
     @classmethod
     def get_field_list(self):
-        return ['id', 'app_id', 'act_id', 'user_id', 'open_id', 'user_nick', 'asset_type', 'asset_object_id', 'handler_name', 'request_code', 'log_title', 'info_desc', 'info_json', 'is_notice', 'notice_date', 'create_day', 'create_date']
+        return ['id', 'app_id', 'act_id','ascription_type', 'user_id', 'open_id', 'user_nick', 'asset_type', 'asset_object_id', 'handler_name', 'request_code', 'log_title', 'info_desc', 'info_json', 'is_notice', 'notice_date', 'create_day', 'create_date']
 
     @classmethod
     def get_primary_key(self):
