@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-27 10:57:24
-@LastEditTime: 2021-09-02 15:31:21
+@LastEditTime: 2022-01-21 16:34:17
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -43,6 +43,7 @@ class TaoPayOrder:
         self.sub_pay_order_no = ""  # 淘宝子订单号
         self.order_status = ""  # 订单状态
         self.asset_type = 0  # 资产类型(1-次数2-积分3-价格档位)
+        self.asset_object_name = ""  # 资产对象名称
         self.asset_object_id = ""  # 资产对象标识
         self.surplus_count = 0  # 剩余资产值
         self.prize_ids = ""  # 奖品ID列表（逗号隔开）
@@ -63,7 +64,7 @@ class TaoPayOrder:
 
     @classmethod
     def get_field_list(self):
-        return ['id', 'ascription_type', 'app_id', 'act_id', 'user_id', 'open_id', 'user_nick', 'goods_code', 'goods_name', 'sku_id', 'sku_name', 'buy_num', 'pay_price', 'main_pay_order_no', 'sub_pay_order_no', 'order_status', 'asset_type', 'asset_object_id', 'surplus_count', 'prize_ids', 'create_date', 'pay_date', 'i1', 'i2', 'i3', 'i4', 'i5', 's1', 's2', 's3', 's4', 's5', 'd1', 'd2']
+        return ['id', 'ascription_type', 'app_id', 'act_id', 'user_id', 'open_id', 'user_nick', 'goods_code', 'goods_name', 'sku_id', 'sku_name', 'buy_num', 'pay_price', 'main_pay_order_no', 'sub_pay_order_no', 'order_status', 'asset_type', 'asset_object_name', 'asset_object_id', 'surplus_count', 'prize_ids', 'create_date', 'pay_date', 'i1', 'i2', 'i3', 'i4', 'i5', 's1', 's2', 's3', 's4', 's5', 'd1', 'd2']
 
     @classmethod
     def get_primary_key(self):
