@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-22 10:59:39
-@LastEditTime: 2021-09-02 17:19:36
+@LastEditTime: 2022-01-24 10:11:52
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -35,6 +35,7 @@ class UserInfo:
         self.union_id = ""  # union_id
         self.open_id = ""  # open_id
         self.user_nick = ""  # 昵称
+        self.user_nick_encrypt = ""  # 昵称加密值
         self.avatar = ""  # 头像
         self.is_auth = 0  # 是否授权（1是0否）
         self.is_new = 0  # 是否新用户
@@ -64,7 +65,7 @@ class UserInfo:
 
     @classmethod
     def get_field_list(self):
-        return ['id', 'id_md5', 'app_id', 'act_id', 'user_id', 'union_id', 'open_id', 'user_nick', 'avatar', 'is_auth', 'is_new', 'pay_price', 'pay_num', 'login_token', 'user_state', 'is_member', 'is_member_before', 'is_favor', 'is_favor_before', 'relieve_date', 'create_date', 'modify_date', 'i1', 'i2', 'i3', 'i4', 'i5', 's1', 's2', 's3', 's4', 's5', 'd1', 'd2']
+        return ['id', 'id_md5', 'app_id', 'act_id', 'user_id', 'union_id', 'open_id', 'user_nick', 'user_nick_encrypt', 'avatar', 'is_auth', 'is_new', 'pay_price', 'pay_num', 'login_token', 'user_state', 'is_member', 'is_member_before', 'is_favor', 'is_favor_before', 'relieve_date', 'create_date', 'modify_date', 'i1', 'i2', 'i3', 'i4', 'i5', 's1', 's2', 's3', 's4', 's5', 'd1', 'd2']
 
     @classmethod
     def get_primary_key(self):
