@@ -2,13 +2,15 @@
 """
 :Author: HuangJianYi
 :Date: 2020-06-02 14:32:40
-@LastEditTime: 2022-04-27 10:10:47
+@LastEditTime: 2022-06-30 14:42:56
 @LastEditors: HuangJianYi
 :description: 枚举类
 """
 
 from enum import Enum
+from enum import unique
 
+@unique
 class OperationType(Enum):
     """
     :description: 用户操作日志类型
@@ -19,6 +21,7 @@ class OperationType(Enum):
     review = 4 #还原
     copy = 5 #复制
 
+@unique
 class TaskType(Enum):
     """
     docstring：任务类型 业务的自定义任务类型从201起
