@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-11 09:10:33
-@LastEditTime: 2022-07-22 16:24:47
+@LastEditTime: 2022-08-16 14:00:33
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -316,7 +316,7 @@ class FrameBaseModel():
         :last_editors: HuangJianYi
         """
         invoke_result_data = InvokeResultData()
-        user_info_model = UserInfoModel(sub_table=self.get_business_sub_table("user_info_tb", {"act_id": act_id, "user_id": 0}),context=self.context)
+        user_info_model = UserInfoModel(context=self.context)
         id_md5 = CryptoHelper.md5_encrypt_int(f"{act_id}_{user_id}")
         user_info_dict = user_info_model.get_cache_dict("id_md5=%s", limit="1", params=[id_md5], dependency_key=DependencyKey.user_info(act_id,id_md5))
         if not user_info_dict:
