@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-02 09:44:36
-@LastEditTime: 2022-06-29 11:59:02
+@LastEditTime: 2022-07-15 16:57:42
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -30,9 +30,9 @@ class IpBaseModel():
         :return: 
         :last_editors: HuangJianYi
         """
-        dependency_key_list = [f"ip_info_list:actid_{act_id}"]
+        dependency_key_list = [DependencyKey.ip_info_list(act_id)]
         if ip_id:
-            dependency_key_list.append(f"ip_info:ipid_{ip_id}")
+            dependency_key_list.append(DependencyKey.ip_info(ip_id))
         IpInfoModel().delete_dependency_key(dependency_key_list, delay_delete_time)
         
     def _delete_ip_type_dependency_key(self, act_id, type_id=0, delay_delete_time=0.01):
@@ -44,9 +44,9 @@ class IpBaseModel():
         :return: 
         :last_editors: HuangJianYi
         """
-        dependency_key_list = [f"ip_type_list:actid_{act_id}"]
+        dependency_key_list = [DependencyKey.ip_type(type_id)]
         if type_id:
-            dependency_key_list.append(f"ip_type:typeid_{type_id}")
+            dependency_key_list.append(DependencyKey.ip_type_list(act_id))
         IpTypeModel().delete_dependency_key(dependency_key_list, delay_delete_time)
 
     def save_ip_info(self, app_id,act_id,ip_id,ip_name,ip_pic,show_pic,sort_index,is_release,ip_type,ip_summary):
@@ -140,7 +140,7 @@ class IpBaseModel():
             condition_where.add_condition("is_release=%s")
             params_list.append(is_release)
         if is_cache == True:
-            page_list, total = IpInfoModel(context=self.context).get_cache_dict_page_list(field=field, page_index=page_index, page_size=page_size, where=condition_where.to_string(), group_by="", order_by=order_by, params=params_list, dependency_key=f"ip_info_list:actid_{act_id}", cache_expire=600)
+            page_list, total = IpInfoModel(context=self.context).get_cache_dict_page_list(field=field, page_index=page_index, page_size=page_size, where=condition_where.to_string(), group_by="", order_by=order_by, params=params_list, dependency_key=DependencyKey.ip_info_list(act_id), cache_expire=600)
         else:
             page_list, total = IpInfoModel(context=self.context).get_dict_page_list(field=field, page_index=page_index, page_size=page_size, where=condition_where.to_string(), group_by="", order_by=order_by, params=params_list)
         return page_list, total
@@ -162,7 +162,7 @@ class IpBaseModel():
             invoke_result_data.error_code = "error"
             invoke_result_data.error_message = "ip信息不存在"
             return invoke_result_data
-        is_release = 0 if is_del == 1 else 1
+        is_release = 0
         del_date = SevenHelper.get_now_datetime()
         invoke_result_data.success = ip_info_model.update_table("is_del=%s,is_release=%s,modify_date=%s,del_date=%s", "id=%s", [is_del, is_release, del_date, del_date, ip_id])
         self._delete_ip_info_dependency_key(ip_info_dict["act_id"],ip_id)
@@ -269,7 +269,7 @@ class IpBaseModel():
             condition_where.add_condition("is_release=%s")
             params_list.append(is_release)
         if is_cache == True:
-            page_list, total = IpTypeModel(context=self.context).get_cache_dict_page_list(field=field, page_index=page_index, page_size=page_size, where=condition_where.to_string(), group_by="", order_by=order_by, params=params_list, dependency_key=f"ip_type_list:actid_{act_id}", cache_expire=600)
+            page_list, total = IpTypeModel(context=self.context).get_cache_dict_page_list(field=field, page_index=page_index, page_size=page_size, where=condition_where.to_string(), group_by="", order_by=order_by, params=params_list, dependency_key=DependencyKey.ip_type_list(act_id), cache_expire=600)
         else:
             page_list, total = IpTypeModel(context=self.context).get_dict_page_list(field=field, page_index=page_index, page_size=page_size, where=condition_where.to_string(), group_by="", order_by=order_by, params=params_list)
         return page_list, total
