@@ -60,7 +60,7 @@ class LaunchBaseModel():
             if is_update == True:
                 launch_goods_model.update_table("is_launch=0,is_sync=0,launch_date=%s", "act_id=%s and goods_id=%s", params=[SevenHelper.get_now_datetime(), act_id, old_goods_id])
 
-        total = launch_goods_model.get_total("act_id=%s and goods_id=%s", params=[act_id, goods_id])
+        total = launch_goods_model.get_total("goods_id=%s", params=[goods_id])
         if total <= 0:
             launch_goods = LaunchGoods()
             launch_goods.app_id = app_id
@@ -77,7 +77,7 @@ class LaunchBaseModel():
 
     def add_launch_goods_v2(self, app_id, act_id, goods_ids):
         """
-        :description: 添加投放商品
+        :description: 添加投放商品 投放2.0
         :param app_id：应用标识
         :param act_id：活动标识
         :param goods_ids:商品id串
@@ -237,16 +237,8 @@ class LaunchBaseModel():
             # 淘宝top接口
             invoke_result_data = top_base_model.miniapp_distribution_items_bind(no_launch_goods_ids, online_url, 'false',access_token,app_key, app_secret, is_log)
             if invoke_result_data.success == False:
-                invoke_result_data.success = False
-                invoke_result_data.error_code = "error"
-                invoke_result_data.error_message = "活动不存在"
                 return invoke_result_data
             resp = invoke_result_data.data
-            if "error_message" in resp.keys():
-                invoke_result_data.success = False
-                invoke_result_data.error_code = "error"
-                invoke_result_data.error_message = resp["error_message"]
-                return invoke_result_data
             async_result = resp["miniapp_distribution_items_bind_response"]["model_list"]["distribution_order_bind_target_entity_open_result_dto"][0]["bind_result_list"]["distribution_order_bind_base_dto"]
             for async_result_info in async_result:
                 no_launch_goods = [no_launch_goods for no_launch_goods in no_launch_goods_list if str(no_launch_goods.goods_id) == async_result_info["target_entity_id"]]
@@ -270,16 +262,8 @@ class LaunchBaseModel():
             # 淘宝top接口
             invoke_result_data = top_base_model.miniapp_distribution_items_bind(launch_goods_ids, online_url, 'true',access_token,app_key, app_secret, is_log)
             if invoke_result_data.success == False:
-                invoke_result_data.success = False
-                invoke_result_data.error_code = "error"
-                invoke_result_data.error_message = "活动不存在"
                 return invoke_result_data
             resp = invoke_result_data.data
-            if "error_message" in resp.keys():
-                invoke_result_data.success = False
-                invoke_result_data.error_code = "error"
-                invoke_result_data.error_message = resp["error_message"]
-                return invoke_result_data
             async_result = resp["miniapp_distribution_items_bind_response"]["model_list"]["distribution_order_bind_target_entity_open_result_dto"][0]["bind_result_list"]["distribution_order_bind_base_dto"]
             for async_result_info in async_result:
                 launch_goods = [launch_goods for launch_goods in launch_goods_list if str(launch_goods.goods_id) == async_result_info["target_entity_id"]]
@@ -416,11 +400,41 @@ class LaunchBaseModel():
         :last_editors: HuangJianYi
         """
         invoke_result_data = InvokeResultData()
-        ActInfoModel(context=self).update_table("is_launch=1", "id=%s", params=act_id)
-        ActBaseModel(context=self)._delete_act_info_dependency_key(app_id,act_id)
         if close_goods_id != "":
             close_goods_id_list = list(set(close_goods_id.split(",")))
             LaunchGoodsModel(context=self).update_table("is_launch=0,launch_date=%s", "act_id=%s and "+ SevenHelper.get_condition_by_str_list("goods_id",close_goods_id_list), params=[SevenHelper.get_now_datetime(),act_id])
+        #保存投放计划信息
+        tb_launch_plan = None
+        if call_back_info != "":
+            call_back_info = SevenHelper.json_loads(call_back_info)
+            for cur_tb_launch_plan in call_back_info["putSuccessList"]:
+                if cur_tb_launch_plan["sceneInfo"]["id"] == 1:
+                    tb_launch_plan = cur_tb_launch_plan
+                    break
+
+        if tb_launch_plan:
+            launch_plan_model = LaunchPlanModel(context=self)
+            launch_plan = launch_plan_model.get_entity("tb_launch_id=%s", params=[tb_launch_plan["id"]])
+            if not launch_plan:
+                launch_plan = LaunchPlan()
+                launch_plan.app_id = app_id
+                launch_plan.act_id = act_id
+                launch_plan.tb_launch_id = tb_launch_plan["id"]
+                launch_plan.launch_url = tb_launch_plan["previewUrl"]
+                launch_plan.start_date = tb_launch_plan["startTime"].replace('年', '-').replace('月', '-').replace('日', ' ') + tb_launch_plan["startTimeBottm"]
+                launch_plan.end_date = tb_launch_plan["endTime"].replace('年', '-').replace('月', '-').replace('日', ' ') + tb_launch_plan["endTimeBottom"]
+                if tb_launch_plan["status"] == "未开始":
+                    launch_plan.status = 0
+                elif tb_launch_plan["status"] == "进行中":
+                    launch_plan.status = 1
+                elif tb_launch_plan["status"] == "已结束":
+                    launch_plan.status = 2
+                launch_plan.create_date = SevenHelper.get_now_datetime()
+                launch_plan.modify_date = SevenHelper.get_now_datetime()
+                launch_plan_model.add_entity(launch_plan)
+            ActInfoModel(context=self).update_table("is_launch=1", "id=%s", params=act_id)
+            ActBaseModel(context=self)._delete_act_info_dependency_key(app_id,act_id)
+            
         return invoke_result_data
 
     def get_launch_plan_status(self, act_id, access_token ,app_key, app_secret):
