@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-05 10:54:36
-@LastEditTime: 2022-07-15 16:56:40
+@LastEditTime: 2022-09-27 18:24:55
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -100,11 +100,12 @@ class ModuleBaseModel():
             page_list, total = ActModuleModel(context=self.context).get_dict_page_list(field="*", page_index=page_index, page_size=page_size, where=where, group_by="", order_by=order_by, params=params_list)
         return page_list, total
 
-    def save_act_module(self,app_id,act_id,module_id,module_name,module_sub_name,start_date,end_date,module_pic,module_desc,price,price_gear_id,ip_id,join_ways,is_fictitious,sort_index,is_release,i1,i2,i3,i4,i5,s1,s2,s3,s4,s5,d1,d2):
+    def save_act_module(self,app_id,act_id,module_id,module_name,module_sub_name,start_date,end_date,module_pic,module_desc,price,price_gear_id,ip_id,join_ways,is_fictitious,sort_index,is_release,i1,i2,i3,i4,i5,s1,s2,s3,s4,s5,d1,d2,business_type):
         """
         :description: 添加活动模块信息
         :param app_id: 应用标识
         :param act_id: 活动标识
+        :param business_type: 业务类型(0无1机台2活动)
         :param module_id: 活动模块标识
         :param module_name: 模块名称
         :param module_sub_name: 模块短名称
@@ -160,6 +161,7 @@ class ModuleBaseModel():
 
         act_module.app_id = app_id
         act_module.act_id = act_id
+        act_module.business_type = business_type
         act_module.module_name = module_name
         act_module.module_sub_name = module_sub_name
         act_module.start_date = start_date
