@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-04 13:41:15
-@LastEditTime: 2022-05-23 11:45:24
+@LastEditTime: 2022-07-15 14:13:11
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -22,10 +22,11 @@ class PrizeBaseModel():
         self.logging_link_error = logging_error
         self.logging_link_info = logging_info
 
-    def _delete_act_prize_dependency_key(self, act_id, prize_id, delay_delete_time=0.01):
+    def _delete_act_prize_dependency_key(self, act_id, model_id, prize_id, delay_delete_time=0.01):
         """
         :description: 删除活动奖品依赖建
         :param act_id: 活动标识
+        :param model_id: 模块标识
         :param prize_id: 奖品标识
         :param delay_delete_time: 延迟删除时间，传0则不进行延迟
         :return: 
@@ -33,9 +34,12 @@ class PrizeBaseModel():
         """
         dependency_key_list = []
         if prize_id:
-            dependency_key_list.append(f"act_prize:prizeid_{prize_id}")
+            dependency_key_list.append(DependencyKey.act_prize(prize_id))
         if act_id:
-            dependency_key_list.append(f"act_prize_list:actid_{act_id}")
+            if model_id:
+                dependency_key_list.append(DependencyKey.act_prize_list(act_id, model_id))
+            else:
+                dependency_key_list.append(DependencyKey.act_prize_list(act_id))
         ActPrizeModel().delete_dependency_key(dependency_key_list,delay_delete_time)
 
 
@@ -50,8 +54,7 @@ class PrizeBaseModel():
         """
         act_prize_model = ActPrizeModel(context=self.context)
         if is_cache:
-            dependency_key = f"act_prize:prizeid_{prize_id}"
-            act_prize_dict = act_prize_model.get_cache_dict_by_id(prize_id,dependency_key=dependency_key)
+            act_prize_dict = act_prize_model.get_cache_dict_by_id(prize_id,dependency_key=DependencyKey.act_prize(prize_id))
         else:
             act_prize_dict = act_prize_model.get_dict_by_id(prize_id)
         if is_filter == True:
@@ -89,7 +92,7 @@ class PrizeBaseModel():
         if is_del !=-1:
             where += " and is_del=%s"
             params_list.append(is_del)
-        if module_id !=0:
+        if module_id:
             where += " and module_id=%s"
             params_list.append(module_id)
         if prize_name:
@@ -97,7 +100,7 @@ class PrizeBaseModel():
             params_list.append(prize_name)
         act_prize_model = ActPrizeModel(context=self.context)
         if is_cache:
-            page_list, total = act_prize_model.get_cache_dict_page_list(field=field, page_index=page_index, page_size=page_size, where=where, group_by="", order_by=order_by, params=params_list,dependency_key=f"act_prize_list:actid_{act_id}")
+            page_list, total = act_prize_model.get_cache_dict_page_list(field=field, page_index=page_index, page_size=page_size, where=where, group_by="", order_by=order_by, params=params_list,dependency_key=DependencyKey.act_prize_list(act_id,module_id))
         else:
             page_list, total = act_prize_model.get_dict_page_list(field=field, page_index=page_index, page_size=page_size, where=where, group_by="", order_by=order_by, params=params_list)
         return page_list, total
@@ -231,7 +234,7 @@ class PrizeBaseModel():
         result["new"] = act_prize
         result["old"] = old_act_prize
         invoke_result_data.data = result
-        self._delete_act_prize_dependency_key(act_id,act_prize.id)
+        self._delete_act_prize_dependency_key(act_id,module_id,act_prize.id)
         return invoke_result_data
 
     def save_tao_coupon(self,app_id,act_id,prize_id,coupon_type,right_ename,pool_id,coupon_start_date,coupon_end_date,coupon_url,coupon_price,use_sill_price):
@@ -273,8 +276,7 @@ class PrizeBaseModel():
         tao_coupon.modify_date = SevenHelper.get_now_datetime()
         tao_coupon.id = tao_coupon_model.add_update_entity(tao_coupon, update_sql="coupon_type=%s,right_ename=%s,pool_id=%s,coupon_start_date=%s,coupon_end_date=%s,coupon_url=%s,coupon_price=%s,use_sill_price=%s,modify_date=%s",params=[coupon_type,right_ename,pool_id,coupon_start_date,coupon_end_date,coupon_url,coupon_price,use_sill_price,tao_coupon.modify_date])
         invoke_result_data.data=tao_coupon.id
-        tao_coupon_model.delete_dependency_key(f"coupon:id_{tao_coupon.id}")
-        tao_coupon_model.delete_dependency_key(f"coupon_list:id_{act_id}")
+        tao_coupon_model.delete_dependency_key([DependencyKey.coupon(tao_coupon.id),DependencyKey.coupon_list(act_id)])
         return invoke_result_data
 
     def update_act_prize_status(self,app_id,prize_id,is_del):
@@ -297,7 +299,7 @@ class PrizeBaseModel():
         is_release = 0 if is_del == 1 else 1
         modify_date = SevenHelper.get_now_datetime()
         invoke_result_data.success = act_prize_model.update_table("is_del=%s,is_release=%s,modify_date=%s", "id=%s", [is_del, is_release, modify_date, prize_id])
-        self._delete_act_prize_dependency_key(act_prize_dict["act_id"],prize_id)
+        self._delete_act_prize_dependency_key(act_prize_dict["act_id"],act_prize_dict["module_id"],prize_id)
         return invoke_result_data
 
     def release_act_prize(self,app_id,prize_id,is_release):
@@ -319,5 +321,5 @@ class PrizeBaseModel():
             return invoke_result_data
         modify_date = SevenHelper.get_now_datetime()
         invoke_result_data.success = act_prize_model.update_table("modify_date=%s,is_release=%s", "id=%s", [modify_date, is_release, prize_id])
-        self._delete_act_prize_dependency_key(act_prize_dict["act_id"],prize_id)
+        self._delete_act_prize_dependency_key(act_prize_dict["act_id"],act_prize_dict["module_id"],prize_id)
         return invoke_result_data
