@@ -2,7 +2,7 @@
 """
 :Author: HuangJianYi
 :Date: 2020-05-02 15:17:41
-@LastEditTime: 2022-07-15 15:08:12
+@LastEditTime: 2022-09-26 16:01:21
 @LastEditors: HuangJianYi
 :description: 自定义实体模型
 """
@@ -227,6 +227,16 @@ class DependencyKey():
         """
         return f"cms_info_list:placeid_{place_id}"
 
+    @classmethod
+    def dict_info_list(self, parent_id):
+        """
+        :description: 字典信息列表
+        :param parent_id: 父节点标识
+        :return str
+        :last_editors: HuangJianYi
+        """
+        return f"dict_info_list:parentid_{parent_id}"
+
     @classmethod
     def ip_info(self, ip_id):
         """
