@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2022-01-10 11:31:34
-@LastEditTime: 2022-01-11 11:48:07
+@LastEditTime: 2022-01-13 18:12:21
 @LastEditors: HuangJianYi
 @Description: 抖店接口业务模型
 """
@@ -55,12 +55,12 @@ class ShakeShopBaseModel():
         else:
             self._gate_way = 'https://openapi-fxg.jinritemai.com'
         self._version = 2
-        redis_token = SevenHelper.redis_init().get(f"shakeshop_access_token:{str(app_key)}")
+        redis_token = SevenHelper.redis_init().get(f"shakeshop_access_token:{str(app_key)}_{self._test_mode}")
         if redis_token:
             redis_token = json.loads(redis_token)
         self._token = redis_token
         self._sign_method = 'hmac-sha256'
-        if not self._token:
+        if self._token:
             if self._token.get('expires_in') - int(time.time()) < 3000:
                 self._refresh_token()
         else:
@@ -113,7 +113,7 @@ class ShakeShopBaseModel():
         :return 
         :last_editors: HuangJianYi
         """
-        request_redis_key = f"shakeshop_access_token:{str(self._app_key)}"
+        request_redis_key = f"shakeshop_access_token:{str(self._app_key)}_{self._test_mode}"
         if SevenHelper.is_continue_request(request_redis_key, 2000) == True:
             return False
         if self._app_type == "TOOL" and not code:
@@ -135,7 +135,7 @@ class ShakeShopBaseModel():
         if result and result.get('err_no') == 0 and result.get('data'):
             self._token = result.get('data')
             self._token.update({'expires_in': int(time.time()) + result.get('data').get('expires_in')})
-            SevenHelper.redis_init().set(f"shakeshop_access_token:{str(self._app_key )}", json.dumps(self._token), ex=3600)
+            SevenHelper.redis_init().set(f"shakeshop_access_token:{str(self._app_key )}_{self._test_mode}", json.dumps(self._token), ex=3600)
             return True
         return False
 
@@ -162,7 +162,7 @@ class ShakeShopBaseModel():
         :return 
         :last_editors: HuangJianYi
         """
-        request_redis_key = f"shakeshop_access_token:{str(self._app_key)}"
+        request_redis_key = f"shakeshop_access_token:{str(self._app_key)}_{self._test_mode}"
         if SevenHelper.is_continue_request(request_redis_key, 2000) == True:
             return False
         path = '/token/refresh'
@@ -176,7 +176,7 @@ class ShakeShopBaseModel():
         if result and result.get('err_no') == 0 and result.get('data'):
             self._token = result.get('data')
             self._token.update({'expires_in': int(time.time()) + result.get('data').get('expires_in')})
-            SevenHelper.redis_init().set(f"shakeshop_access_token:{str(self._app_key )}", json.dumps(self._token), ex=3600)
+            SevenHelper.redis_init().set(f"shakeshop_access_token:{str(self._app_key )}_{self._test_mode}", json.dumps(self._token), ex=3600)
 
     def _request(self, path: str, params: dict, token_request: bool = False, is_log: bool = False) -> json:
         """
@@ -204,28 +204,16 @@ class ShakeShopBaseModel():
                 url = self._gate_way + '{}?app_key={}&method={}&access_token={}&param_json={}&timestamp={}&v={}&sign_method={}&sign={}'.format(path, self._app_key, method, access_token, param_json, timestamp, self._version, self._sign_method, sign)
             if is_log == True:
                 if self.context:
-                    self.context.logging_link_info('Request url: {}'.format(url))
-                    self.context.logging_link_info('Request headers: {}'.format(headers))
-                    self.context.logging_link_info('Request params: {}'.format(param_json))
-                    self.context.logging_link_info('Request url: {}'.format(url))
-                    self.context.logging_link_info('Request url: {}'.format(url))
+                    self.context.logging_link_info(f'Request url:{url},Request headers:{headers},Request params:{param_json}')
                 elif self.logging_link_info:
-                    self.logging_link_info('Request url: {}'.format(url))
-                    self.logging_link_info('Request headers: {}'.format(headers))
-                    self.logging_link_info('Request params: {}'.format(param_json))
-                    self.logging_link_info('Request url: {}'.format(url))
-                    self.logging_link_info('Request url: {}'.format(url))
+                    self.logging_link_info(f'Request url:{url},Request headers:{headers},Request params:{param_json}')
 
             response = requests.post(url=url, data=param_json, headers=headers, proxies=self._proxy)
             if is_log == True:
                 if self.context:
-                    self.context.logging_link_info('Response status code: {}'.format(response.status_code))
-                    self.context.logging_link_info('Response headers: {}'.format(response.headers))
-                    self.context.logging_link_info('Response content: {}'.format(response.content.decode('UTF-8')))
+                    self.context.logging_link_info(f'Response status code: {response.status_code},Response headers:{response.headers},Response content:' + response.content.decode('UTF-8'))
                 elif self.logging_link_info:
-                    self.logging_link_info('Response status code: {}'.format(response.status_code))
-                    self.logging_link_info('Response headers: {}'.format(response.headers))
-                    self.logging_link_info('Response content: {}'.format(response.content.decode('UTF-8')))
+                    self.logging_link_info(f'Response status code: {response.status_code},Response headers:{response.headers},Response content:' + response.content.decode('UTF-8'))
             if response.status_code != 200:
                 return None
             return json.loads(response.content)
@@ -236,19 +224,20 @@ class ShakeShopBaseModel():
                 self.logging_link_error(traceback.format_exc())
             return None
 
-    def request(self, path: str, params: dict) -> json:
+    def request(self, path: str, params: dict, is_log: bool = False) -> json:
         """
         :description: 请求抖店API接口
         :param path: 调用的API接口地址，示例：'/material/uploadImageSync'
         :param params: 业务参数字典，示例：{'folder_id':'70031975314169695161250','url':'http://www.demo.com/demo.jpg','material_name':'demo.jpg'}
+        :param is_log: 是否记录日志
         :return 
         :last_editors: HuangJianYi
         """
-        return self._request(path=path, params=params)
+        return self._request(path=path, params=params, is_log=is_log)
 
     def callback(self, headers: dict, body: bytes, is_log: bool = False) -> json:
         """
-        :description: 验证处理消息推送服务收到信息
+        :description: 验证处理消息推送服务收到信息Md5解密模式
         :param headers: headers
         :param body: body
         :param is_log: 是否记录日志
@@ -256,16 +245,11 @@ class ShakeShopBaseModel():
         :last_editors: HuangJianYi
         """
         data: str = body.decode('UTF-8')
-        if self._logger:
-            self._logger.debug('Callback Header: %s' % headers)
-            self._logger.debug('Callback Body: %s' % body)
         if is_log == True:
             if self.context:
-                self.context.logging_link_info('Callback Header: %s' % headers)
-                self.context.logging_link_info('Callback Body: %s' % body)
+                self.context.logging_link_info(f'Callback Header:{headers},Callback Body:{body}')
             elif self.logging_link_info:
-                self.logging_link_info('Callback Header: %s' % headers)
-                self.logging_link_info('Callback Body: %s' % body)
+                self.logging_link_info(f'Callback Header:{headers},Callback Body:{body}')
         if not data:
             return None
         if headers.get('app-id') != self._app_key:
