@@ -2,7 +2,7 @@
 """
 :Author: HuangJianYi
 :Date: 2020-08-12 09:06:24
-@LastEditTime: 2022-07-21 11:25:21
+@LastEditTime: 2022-07-27 15:26:36
 @LastEditors: HuangJianYi
 :description: 淘宝top接口基础类
 """
@@ -16,7 +16,7 @@ class TopBaseModel():
     """
     :description: 淘宝top接口业务模型
     """
-    def __init__(self,context=None,logging_error=None,logging_info=None):
+    def __init__(self, context=None, logging_error=None, logging_info=None):
         self.context = context
         self.logging_link_error = logging_error
         self.logging_link_info = logging_info
@@ -109,7 +109,7 @@ class TopBaseModel():
             req.clients = "taobao,tmall"
             req.description = description
 
-            invoke_result_data = self.get_shop(access_token,app_key,app_secret, is_log)
+            invoke_result_data = self.get_shop(access_token, app_key, app_secret, is_log)
             shop_info = invoke_result_data.data if invoke_result_data.success == True else {}
 
             req.ext_json = "{ \"name\":\"" + app_name + "\"}"
@@ -183,7 +183,7 @@ class TopBaseModel():
                         invoke_result_data.data = {"icon": icon, "app_name": app_name}
                         return invoke_result_data
 
-    def version_upgrade(self, app_id, client_template_id, client_ver, access_token,app_key, app_secret, app_info, is_log=False):
+    def version_upgrade(self, app_id, client_template_id, client_ver, access_token, app_key, app_secret, app_info, is_log=False):
         """
         :description: app更新 接口权限包：商家应用-模板实例化权限包
         :param app_id:app_id
@@ -240,7 +240,7 @@ class TopBaseModel():
                         return invoke_result_data
             return invoke_result_data
 
-    def get_sku_name(self, num_iids, sku_id, access_token,app_key, app_secret,is_log=False):
+    def get_sku_name(self, num_iids, sku_id, access_token, app_key, app_secret,is_log=False):
         """
         :description: 获取sku名称
         :param num_iids：num_iids
@@ -296,7 +296,7 @@ class TopBaseModel():
                         return invoke_result_data
             return invoke_result_data
 
-    def get_buy_order_info(self, order_no, access_token,app_key, app_secret,is_log=False):
+    def get_buy_order_info(self, order_no, access_token, app_key, app_secret,is_log=False):
         """
         :description: 获取单笔订单
         :param order_no：订单编号
@@ -416,7 +416,7 @@ class TopBaseModel():
                         return invoke_result_data
             return invoke_result_data
 
-    def get_refund_order_list(self, buyer_nick, access_token,app_key, app_secret, start_modified="", end_modified="",page_size=50,is_log=False):
+    def get_refund_order_list(self, buyer_nick, access_token, app_key, app_secret, start_modified="", end_modified="", page_size=50, is_log=False, open_id=""):
         """
         :description: 获取淘宝退款订单
         :param buyer_nick：用户昵称
@@ -427,6 +427,7 @@ class TopBaseModel():
         :param end_modified：结束时间
         :param page_size：页大小
         :param is_log：是否记录返回信息
+        :param open_id：open_id
         :return InvokeResultData
         :last_editors: HuangJianYi
         """
@@ -440,11 +441,13 @@ class TopBaseModel():
             # refund_id：退款单号, tid：淘宝交易单号, oid：子订单号, title：商品名称 , total_fee：订单总价, status：退款状态,
             # created：退款申请时间, refund_fee：退款金额, modified：更新时间, num: 购买数量
             req.type = "fixed"
-            req.buyer_nick = buyer_nick
+            if buyer_nick:
+                req.buyer_nick = buyer_nick
             req.page_size = page_size
             req.page_no = 1
             req.use_has_next = "true"
-
+            if open_id:
+                req.buyer_open_uid = open_id
             if start_modified == "":
                 start_timestamp = TimeHelper.get_now_timestamp() - 90 * 24 * 60 * 60
                 start_modified = TimeHelper.timestamp_to_format_time(start_timestamp)
@@ -486,7 +489,7 @@ class TopBaseModel():
                         return invoke_result_data
             return invoke_result_data
 
-    def online_app(self, app_id, template_id, template_version, app_version, access_token,app_key, app_secret, is_log=False):
+    def online_app(self, app_id, template_id, template_version, app_version, access_token, app_key, app_secret, is_log=False):
         """
         :description: app上线
         :param app_id：app_id
@@ -538,7 +541,7 @@ class TopBaseModel():
                         return invoke_result_data
             return invoke_result_data
 
-    def get_shop(self, access_token,app_key,app_secret,is_log=False):
+    def get_shop(self, access_token, app_key, app_secret, is_log=False):
         """
         :description: 获取店铺信息
         :param access_token：access_token
@@ -581,7 +584,7 @@ class TopBaseModel():
                         return invoke_result_data
             return invoke_result_data
 
-    def get_user_seller(self, access_token,app_key, app_secret,is_log=False):
+    def get_user_seller(self, access_token, app_key, app_secret, is_log=False):
         """
         :description: 获取关注店铺用户信息
         :param access_token：access_token
@@ -891,7 +894,7 @@ class TopBaseModel():
                         return invoke_result_data
             return invoke_result_data
 
-    def miniapp_distribution_items_bind(self, goods_ids, url, status, access_token,app_key, app_secret, is_log=False):
+    def miniapp_distribution_items_bind(self, goods_ids, url, status, access_token, app_key, app_secret, is_log=False):
         """
         :description: 小程序投放-商品绑定/解绑（提供给使用了投放插件的服务商，可以调用该API实现帮助商家更新已创建的投放单中的绑定商品信息。）
         :param goods_ids：商品id列表逗号，分隔
@@ -986,7 +989,7 @@ class TopBaseModel():
                         return invoke_result_data
             return invoke_result_data
     
-    def alibaba_benefit_query(self, right_ename,access_token,app_key, app_secret, is_log=False):
+    def alibaba_benefit_query(self, right_ename, access_token, app_key, app_secret, is_log=False):
         """
         :description: 查询优惠券详情信息
         :param right_ename:奖池ID
@@ -1152,7 +1155,7 @@ class TopBaseModel():
                     is_member = True
         return is_member
 
-    def get_join_member_url(self, access_token,app_key, app_secret,is_log=False):
+    def get_join_member_url(self, access_token, app_key, app_secret, is_log=False):
         """
         :description: 获取加入会员地址
         :param access_token:access_token
@@ -1201,7 +1204,7 @@ class TopBaseModel():
                         return invoke_result_data
             return invoke_result_data
 
-    def open_trade_special_items_query(self, app_id, access_token,app_key, app_secret,is_log=False):
+    def open_trade_special_items_query(self, app_id, access_token, app_key, app_secret, is_log=False):
         """
         :description: 专属下单查询
         :param app_id：app_id
@@ -1246,7 +1249,7 @@ class TopBaseModel():
                         return invoke_result_data
             return invoke_result_data
 
-    def open_trade_special_userk_mark(self, goods_id, open_id, access_token,app_key, app_secret,is_log=False):
+    def open_trade_special_userk_mark(self, goods_id, open_id, access_token, app_key, app_secret, is_log=False):
         """
         :description: 专属下单可购买用户标记
         :param goods_id：商品id
@@ -1301,7 +1304,7 @@ class TopBaseModel():
                         return invoke_result_data
             return invoke_result_data
 
-    def open_trade_special_items_bind(self, app_id, goods_id, access_token,app_key, app_secret, is_log=False):
+    def open_trade_special_items_bind(self, app_id, goods_id, access_token, app_key, app_secret, is_log=False):
         """
         :description: 专属下单商品绑定
         :param app_id：app_id
@@ -1353,7 +1356,7 @@ class TopBaseModel():
                         return invoke_result_data
             return invoke_result_data
 
-    def get_project_code(self, user_nick, access_token,app_key, app_secret,is_log=False):
+    def get_project_code(self, user_nick, access_token, app_key, app_secret, is_log=False):
         """
         :description: 获取项目编码
         :param user_nick：用户昵称
@@ -1378,7 +1381,7 @@ class TopBaseModel():
                 self.logging_link_error(traceback.format_exc())
             return ""
 
-    def get_vas_subscribe(self, user_nick, access_token,app_key, app_secret,is_log=False):
+    def get_vas_subscribe(self, user_nick, access_token, app_key, app_secret, is_log=False):
         """
         :description:订购关系查询 用于ISV根据登录进来的淘宝会员名查询该为该会员开通哪些收费项目，ISV只能查询自己名下的应用及收费项目的订购情况
         :param user_nick：用户昵称
@@ -1461,7 +1464,7 @@ class TopBaseModel():
             invoke_result_data.success = False
             return invoke_result_data
 
-    def get_crm_point_available(self, mix_nick, access_token, app_key, app_secret, is_log=False):
+    def get_crm_point_available(self, mix_nick, access_token, app_key, app_secret, is_log=False, open_id=""):
         """
         :description: 获取店铺会员积分
         :param mix_nick：混淆昵称
@@ -1469,6 +1472,7 @@ class TopBaseModel():
         :param app_key:app_key
         :param app_secret:app_secret
         :param is_log：是否记录返回信息
+        :param open_id：open_id
         :return 返回店铺会员积分
         :last_editors: HuangJianYi
         """
@@ -1476,7 +1480,10 @@ class TopBaseModel():
         try:
             top.setDefaultAppInfo(app_key, app_secret)
             req = top.api.CrmPointAvailableGetRequest()
-            req.mix_nick = mix_nick
+            if mix_nick:
+                req.mix_nick = mix_nick
+            if open_id:
+                req.open_uid = open_id
             resp = req.getResponse(access_token)
             if is_log:
                 log_info = "【req】:" + SevenHelper.json_dumps(req) + "【resp】:" + str(resp) +  "【access_token】：" + access_token + "【获取店铺会员积分】"
